datadog\_api\_client.v2.model
=============================

api\_error\_response
--------------------

.. automodule:: datadog_api_client.v2.model.api_error_response
   :members:
   :show-inheritance:

api\_key\_create\_attributes
----------------------------

.. automodule:: datadog_api_client.v2.model.api_key_create_attributes
   :members:
   :show-inheritance:

api\_key\_create\_data
----------------------

.. automodule:: datadog_api_client.v2.model.api_key_create_data
   :members:
   :show-inheritance:

api\_key\_create\_request
-------------------------

.. automodule:: datadog_api_client.v2.model.api_key_create_request
   :members:
   :show-inheritance:

api\_key\_relationships
-----------------------

.. automodule:: datadog_api_client.v2.model.api_key_relationships
   :members:
   :show-inheritance:

api\_key\_response
------------------

.. automodule:: datadog_api_client.v2.model.api_key_response
   :members:
   :show-inheritance:

api\_key\_response\_included\_item
----------------------------------

.. automodule:: datadog_api_client.v2.model.api_key_response_included_item
   :members:
   :show-inheritance:

api\_key\_update\_attributes
----------------------------

.. automodule:: datadog_api_client.v2.model.api_key_update_attributes
   :members:
   :show-inheritance:

api\_key\_update\_data
----------------------

.. automodule:: datadog_api_client.v2.model.api_key_update_data
   :members:
   :show-inheritance:

api\_key\_update\_request
-------------------------

.. automodule:: datadog_api_client.v2.model.api_key_update_request
   :members:
   :show-inheritance:

api\_keys\_response
-------------------

.. automodule:: datadog_api_client.v2.model.api_keys_response
   :members:
   :show-inheritance:

api\_keys\_sort
---------------

.. automodule:: datadog_api_client.v2.model.api_keys_sort
   :members:
   :show-inheritance:

api\_keys\_type
---------------

.. automodule:: datadog_api_client.v2.model.api_keys_type
   :members:
   :show-inheritance:

application\_key\_create\_attributes
------------------------------------

.. automodule:: datadog_api_client.v2.model.application_key_create_attributes
   :members:
   :show-inheritance:

application\_key\_create\_data
------------------------------

.. automodule:: datadog_api_client.v2.model.application_key_create_data
   :members:
   :show-inheritance:

application\_key\_create\_request
---------------------------------

.. automodule:: datadog_api_client.v2.model.application_key_create_request
   :members:
   :show-inheritance:

application\_key\_relationships
-------------------------------

.. automodule:: datadog_api_client.v2.model.application_key_relationships
   :members:
   :show-inheritance:

application\_key\_response
--------------------------

.. automodule:: datadog_api_client.v2.model.application_key_response
   :members:
   :show-inheritance:

application\_key\_response\_included\_item
------------------------------------------

.. automodule:: datadog_api_client.v2.model.application_key_response_included_item
   :members:
   :show-inheritance:

application\_key\_update\_attributes
------------------------------------

.. automodule:: datadog_api_client.v2.model.application_key_update_attributes
   :members:
   :show-inheritance:

application\_key\_update\_data
------------------------------

.. automodule:: datadog_api_client.v2.model.application_key_update_data
   :members:
   :show-inheritance:

application\_key\_update\_request
---------------------------------

.. automodule:: datadog_api_client.v2.model.application_key_update_request
   :members:
   :show-inheritance:

application\_keys\_sort
-----------------------

.. automodule:: datadog_api_client.v2.model.application_keys_sort
   :members:
   :show-inheritance:

application\_keys\_type
-----------------------

.. automodule:: datadog_api_client.v2.model.application_keys_type
   :members:
   :show-inheritance:

audit\_logs\_event
------------------

.. automodule:: datadog_api_client.v2.model.audit_logs_event
   :members:
   :show-inheritance:

audit\_logs\_event\_attributes
------------------------------

.. automodule:: datadog_api_client.v2.model.audit_logs_event_attributes
   :members:
   :show-inheritance:

audit\_logs\_event\_type
------------------------

.. automodule:: datadog_api_client.v2.model.audit_logs_event_type
   :members:
   :show-inheritance:

audit\_logs\_events\_response
-----------------------------

.. automodule:: datadog_api_client.v2.model.audit_logs_events_response
   :members:
   :show-inheritance:

audit\_logs\_query\_filter
--------------------------

.. automodule:: datadog_api_client.v2.model.audit_logs_query_filter
   :members:
   :show-inheritance:

audit\_logs\_query\_options
---------------------------

.. automodule:: datadog_api_client.v2.model.audit_logs_query_options
   :members:
   :show-inheritance:

audit\_logs\_query\_page\_options
---------------------------------

.. automodule:: datadog_api_client.v2.model.audit_logs_query_page_options
   :members:
   :show-inheritance:

audit\_logs\_response\_links
----------------------------

.. automodule:: datadog_api_client.v2.model.audit_logs_response_links
   :members:
   :show-inheritance:

audit\_logs\_response\_metadata
-------------------------------

.. automodule:: datadog_api_client.v2.model.audit_logs_response_metadata
   :members:
   :show-inheritance:

audit\_logs\_response\_page
---------------------------

.. automodule:: datadog_api_client.v2.model.audit_logs_response_page
   :members:
   :show-inheritance:

audit\_logs\_response\_status
-----------------------------

.. automodule:: datadog_api_client.v2.model.audit_logs_response_status
   :members:
   :show-inheritance:

audit\_logs\_search\_events\_request
------------------------------------

.. automodule:: datadog_api_client.v2.model.audit_logs_search_events_request
   :members:
   :show-inheritance:

audit\_logs\_sort
-----------------

.. automodule:: datadog_api_client.v2.model.audit_logs_sort
   :members:
   :show-inheritance:

audit\_logs\_warning
--------------------

.. automodule:: datadog_api_client.v2.model.audit_logs_warning
   :members:
   :show-inheritance:

authn\_mapping
--------------

.. automodule:: datadog_api_client.v2.model.authn_mapping
   :members:
   :show-inheritance:

authn\_mapping\_attributes
--------------------------

.. automodule:: datadog_api_client.v2.model.authn_mapping_attributes
   :members:
   :show-inheritance:

authn\_mapping\_create\_attributes
----------------------------------

.. automodule:: datadog_api_client.v2.model.authn_mapping_create_attributes
   :members:
   :show-inheritance:

authn\_mapping\_create\_data
----------------------------

.. automodule:: datadog_api_client.v2.model.authn_mapping_create_data
   :members:
   :show-inheritance:

authn\_mapping\_create\_relationships
-------------------------------------

.. automodule:: datadog_api_client.v2.model.authn_mapping_create_relationships
   :members:
   :show-inheritance:

authn\_mapping\_create\_request
-------------------------------

.. automodule:: datadog_api_client.v2.model.authn_mapping_create_request
   :members:
   :show-inheritance:

authn\_mapping\_included
------------------------

.. automodule:: datadog_api_client.v2.model.authn_mapping_included
   :members:
   :show-inheritance:

authn\_mapping\_relationships
-----------------------------

.. automodule:: datadog_api_client.v2.model.authn_mapping_relationships
   :members:
   :show-inheritance:

authn\_mapping\_response
------------------------

.. automodule:: datadog_api_client.v2.model.authn_mapping_response
   :members:
   :show-inheritance:

authn\_mapping\_update\_attributes
----------------------------------

.. automodule:: datadog_api_client.v2.model.authn_mapping_update_attributes
   :members:
   :show-inheritance:

authn\_mapping\_update\_data
----------------------------

.. automodule:: datadog_api_client.v2.model.authn_mapping_update_data
   :members:
   :show-inheritance:

authn\_mapping\_update\_relationships
-------------------------------------

.. automodule:: datadog_api_client.v2.model.authn_mapping_update_relationships
   :members:
   :show-inheritance:

authn\_mapping\_update\_request
-------------------------------

.. automodule:: datadog_api_client.v2.model.authn_mapping_update_request
   :members:
   :show-inheritance:

authn\_mappings\_response
-------------------------

.. automodule:: datadog_api_client.v2.model.authn_mappings_response
   :members:
   :show-inheritance:

authn\_mappings\_sort
---------------------

.. automodule:: datadog_api_client.v2.model.authn_mappings_sort
   :members:
   :show-inheritance:

authn\_mappings\_type
---------------------

.. automodule:: datadog_api_client.v2.model.authn_mappings_type
   :members:
   :show-inheritance:

chargeback\_breakdown
---------------------

.. automodule:: datadog_api_client.v2.model.chargeback_breakdown
   :members:
   :show-inheritance:

ci\_app\_aggregate\_bucket\_value
---------------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_aggregate_bucket_value
   :members:
   :show-inheritance:

ci\_app\_aggregate\_bucket\_value\_timeseries
---------------------------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_aggregate_bucket_value_timeseries
   :members:
   :show-inheritance:

ci\_app\_aggregate\_bucket\_value\_timeseries\_point
----------------------------------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_aggregate_bucket_value_timeseries_point
   :members:
   :show-inheritance:

ci\_app\_aggregate\_sort
------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_aggregate_sort
   :members:
   :show-inheritance:

ci\_app\_aggregate\_sort\_type
------------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_aggregate_sort_type
   :members:
   :show-inheritance:

ci\_app\_aggregation\_function
------------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_aggregation_function
   :members:
   :show-inheritance:

ci\_app\_compute
----------------

.. automodule:: datadog_api_client.v2.model.ci_app_compute
   :members:
   :show-inheritance:

ci\_app\_compute\_type
----------------------

.. automodule:: datadog_api_client.v2.model.ci_app_compute_type
   :members:
   :show-inheritance:

ci\_app\_computes
-----------------

.. automodule:: datadog_api_client.v2.model.ci_app_computes
   :members:
   :show-inheritance:

ci\_app\_event\_attributes
--------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_event_attributes
   :members:
   :show-inheritance:

ci\_app\_group\_by\_histogram
-----------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_group_by_histogram
   :members:
   :show-inheritance:

ci\_app\_group\_by\_missing
---------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_group_by_missing
   :members:
   :show-inheritance:

ci\_app\_group\_by\_total
-------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_group_by_total
   :members:
   :show-inheritance:

ci\_app\_pipeline\_event
------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_pipeline_event
   :members:
   :show-inheritance:

ci\_app\_pipeline\_event\_type\_name
------------------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_pipeline_event_type_name
   :members:
   :show-inheritance:

ci\_app\_pipeline\_events\_request
----------------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_pipeline_events_request
   :members:
   :show-inheritance:

ci\_app\_pipeline\_events\_response
-----------------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_pipeline_events_response
   :members:
   :show-inheritance:

ci\_app\_pipelines\_aggregate\_request
--------------------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_pipelines_aggregate_request
   :members:
   :show-inheritance:

ci\_app\_pipelines\_aggregation\_buckets\_response
--------------------------------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_pipelines_aggregation_buckets_response
   :members:
   :show-inheritance:

ci\_app\_pipelines\_analytics\_aggregate\_response
--------------------------------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_pipelines_analytics_aggregate_response
   :members:
   :show-inheritance:

ci\_app\_pipelines\_bucket\_response
------------------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_pipelines_bucket_response
   :members:
   :show-inheritance:

ci\_app\_pipelines\_group\_by
-----------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_pipelines_group_by
   :members:
   :show-inheritance:

ci\_app\_pipelines\_query\_filter
---------------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_pipelines_query_filter
   :members:
   :show-inheritance:

ci\_app\_query\_options
-----------------------

.. automodule:: datadog_api_client.v2.model.ci_app_query_options
   :members:
   :show-inheritance:

ci\_app\_query\_page\_options
-----------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_query_page_options
   :members:
   :show-inheritance:

ci\_app\_response\_links
------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_response_links
   :members:
   :show-inheritance:

ci\_app\_response\_metadata
---------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_response_metadata
   :members:
   :show-inheritance:

ci\_app\_response\_page
-----------------------

.. automodule:: datadog_api_client.v2.model.ci_app_response_page
   :members:
   :show-inheritance:

ci\_app\_response\_status
-------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_response_status
   :members:
   :show-inheritance:

ci\_app\_sort
-------------

.. automodule:: datadog_api_client.v2.model.ci_app_sort
   :members:
   :show-inheritance:

ci\_app\_sort\_order
--------------------

.. automodule:: datadog_api_client.v2.model.ci_app_sort_order
   :members:
   :show-inheritance:

ci\_app\_test\_event
--------------------

.. automodule:: datadog_api_client.v2.model.ci_app_test_event
   :members:
   :show-inheritance:

ci\_app\_test\_event\_type\_name
--------------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_test_event_type_name
   :members:
   :show-inheritance:

ci\_app\_test\_events\_request
------------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_test_events_request
   :members:
   :show-inheritance:

ci\_app\_test\_events\_response
-------------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_test_events_response
   :members:
   :show-inheritance:

ci\_app\_tests\_aggregate\_request
----------------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_tests_aggregate_request
   :members:
   :show-inheritance:

ci\_app\_tests\_aggregation\_buckets\_response
----------------------------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_tests_aggregation_buckets_response
   :members:
   :show-inheritance:

ci\_app\_tests\_analytics\_aggregate\_response
----------------------------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_tests_analytics_aggregate_response
   :members:
   :show-inheritance:

ci\_app\_tests\_bucket\_response
--------------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_tests_bucket_response
   :members:
   :show-inheritance:

ci\_app\_tests\_group\_by
-------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_tests_group_by
   :members:
   :show-inheritance:

ci\_app\_tests\_query\_filter
-----------------------------

.. automodule:: datadog_api_client.v2.model.ci_app_tests_query_filter
   :members:
   :show-inheritance:

ci\_app\_warning
----------------

.. automodule:: datadog_api_client.v2.model.ci_app_warning
   :members:
   :show-inheritance:

cloud\_configuration\_compliance\_rule\_options
-----------------------------------------------

.. automodule:: datadog_api_client.v2.model.cloud_configuration_compliance_rule_options
   :members:
   :show-inheritance:

cloud\_configuration\_rego\_rule
--------------------------------

.. automodule:: datadog_api_client.v2.model.cloud_configuration_rego_rule
   :members:
   :show-inheritance:

cloud\_configuration\_rule\_case\_create
----------------------------------------

.. automodule:: datadog_api_client.v2.model.cloud_configuration_rule_case_create
   :members:
   :show-inheritance:

cloud\_configuration\_rule\_compliance\_signal\_options
-------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.cloud_configuration_rule_compliance_signal_options
   :members:
   :show-inheritance:

cloud\_configuration\_rule\_create\_payload
-------------------------------------------

.. automodule:: datadog_api_client.v2.model.cloud_configuration_rule_create_payload
   :members:
   :show-inheritance:

cloud\_configuration\_rule\_options
-----------------------------------

.. automodule:: datadog_api_client.v2.model.cloud_configuration_rule_options
   :members:
   :show-inheritance:

cloud\_configuration\_rule\_type
--------------------------------

.. automodule:: datadog_api_client.v2.model.cloud_configuration_rule_type
   :members:
   :show-inheritance:

cloud\_workload\_security\_agent\_rule\_attributes
--------------------------------------------------

.. automodule:: datadog_api_client.v2.model.cloud_workload_security_agent_rule_attributes
   :members:
   :show-inheritance:

cloud\_workload\_security\_agent\_rule\_create\_attributes
----------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.cloud_workload_security_agent_rule_create_attributes
   :members:
   :show-inheritance:

cloud\_workload\_security\_agent\_rule\_create\_data
----------------------------------------------------

.. automodule:: datadog_api_client.v2.model.cloud_workload_security_agent_rule_create_data
   :members:
   :show-inheritance:

cloud\_workload\_security\_agent\_rule\_create\_request
-------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.cloud_workload_security_agent_rule_create_request
   :members:
   :show-inheritance:

cloud\_workload\_security\_agent\_rule\_creator\_attributes
-----------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.cloud_workload_security_agent_rule_creator_attributes
   :members:
   :show-inheritance:

cloud\_workload\_security\_agent\_rule\_data
--------------------------------------------

.. automodule:: datadog_api_client.v2.model.cloud_workload_security_agent_rule_data
   :members:
   :show-inheritance:

cloud\_workload\_security\_agent\_rule\_response
------------------------------------------------

.. automodule:: datadog_api_client.v2.model.cloud_workload_security_agent_rule_response
   :members:
   :show-inheritance:

cloud\_workload\_security\_agent\_rule\_type
--------------------------------------------

.. automodule:: datadog_api_client.v2.model.cloud_workload_security_agent_rule_type
   :members:
   :show-inheritance:

cloud\_workload\_security\_agent\_rule\_update\_attributes
----------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.cloud_workload_security_agent_rule_update_attributes
   :members:
   :show-inheritance:

cloud\_workload\_security\_agent\_rule\_update\_data
----------------------------------------------------

.. automodule:: datadog_api_client.v2.model.cloud_workload_security_agent_rule_update_data
   :members:
   :show-inheritance:

cloud\_workload\_security\_agent\_rule\_update\_request
-------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.cloud_workload_security_agent_rule_update_request
   :members:
   :show-inheritance:

cloud\_workload\_security\_agent\_rule\_updater\_attributes
-----------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.cloud_workload_security_agent_rule_updater_attributes
   :members:
   :show-inheritance:

cloud\_workload\_security\_agent\_rules\_list\_response
-------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.cloud_workload_security_agent_rules_list_response
   :members:
   :show-inheritance:

confluent\_account\_create\_request
-----------------------------------

.. automodule:: datadog_api_client.v2.model.confluent_account_create_request
   :members:
   :show-inheritance:

confluent\_account\_create\_request\_attributes
-----------------------------------------------

.. automodule:: datadog_api_client.v2.model.confluent_account_create_request_attributes
   :members:
   :show-inheritance:

confluent\_account\_create\_request\_data
-----------------------------------------

.. automodule:: datadog_api_client.v2.model.confluent_account_create_request_data
   :members:
   :show-inheritance:

confluent\_account\_resource\_attributes
----------------------------------------

.. automodule:: datadog_api_client.v2.model.confluent_account_resource_attributes
   :members:
   :show-inheritance:

confluent\_account\_response
----------------------------

.. automodule:: datadog_api_client.v2.model.confluent_account_response
   :members:
   :show-inheritance:

confluent\_account\_response\_attributes
----------------------------------------

.. automodule:: datadog_api_client.v2.model.confluent_account_response_attributes
   :members:
   :show-inheritance:

confluent\_account\_response\_data
----------------------------------

.. automodule:: datadog_api_client.v2.model.confluent_account_response_data
   :members:
   :show-inheritance:

confluent\_account\_type
------------------------

.. automodule:: datadog_api_client.v2.model.confluent_account_type
   :members:
   :show-inheritance:

confluent\_account\_update\_request
-----------------------------------

.. automodule:: datadog_api_client.v2.model.confluent_account_update_request
   :members:
   :show-inheritance:

confluent\_account\_update\_request\_attributes
-----------------------------------------------

.. automodule:: datadog_api_client.v2.model.confluent_account_update_request_attributes
   :members:
   :show-inheritance:

confluent\_account\_update\_request\_data
-----------------------------------------

.. automodule:: datadog_api_client.v2.model.confluent_account_update_request_data
   :members:
   :show-inheritance:

confluent\_accounts\_response
-----------------------------

.. automodule:: datadog_api_client.v2.model.confluent_accounts_response
   :members:
   :show-inheritance:

confluent\_resource\_request
----------------------------

.. automodule:: datadog_api_client.v2.model.confluent_resource_request
   :members:
   :show-inheritance:

confluent\_resource\_request\_attributes
----------------------------------------

.. automodule:: datadog_api_client.v2.model.confluent_resource_request_attributes
   :members:
   :show-inheritance:

confluent\_resource\_request\_data
----------------------------------

.. automodule:: datadog_api_client.v2.model.confluent_resource_request_data
   :members:
   :show-inheritance:

confluent\_resource\_response
-----------------------------

.. automodule:: datadog_api_client.v2.model.confluent_resource_response
   :members:
   :show-inheritance:

confluent\_resource\_response\_attributes
-----------------------------------------

.. automodule:: datadog_api_client.v2.model.confluent_resource_response_attributes
   :members:
   :show-inheritance:

confluent\_resource\_response\_data
-----------------------------------

.. automodule:: datadog_api_client.v2.model.confluent_resource_response_data
   :members:
   :show-inheritance:

confluent\_resource\_type
-------------------------

.. automodule:: datadog_api_client.v2.model.confluent_resource_type
   :members:
   :show-inheritance:

confluent\_resources\_response
------------------------------

.. automodule:: datadog_api_client.v2.model.confluent_resources_response
   :members:
   :show-inheritance:

content\_encoding
-----------------

.. automodule:: datadog_api_client.v2.model.content_encoding
   :members:
   :show-inheritance:

cost\_by\_org
-------------

.. automodule:: datadog_api_client.v2.model.cost_by_org
   :members:
   :show-inheritance:

cost\_by\_org\_attributes
-------------------------

.. automodule:: datadog_api_client.v2.model.cost_by_org_attributes
   :members:
   :show-inheritance:

cost\_by\_org\_response
-----------------------

.. automodule:: datadog_api_client.v2.model.cost_by_org_response
   :members:
   :show-inheritance:

cost\_by\_org\_type
-------------------

.. automodule:: datadog_api_client.v2.model.cost_by_org_type
   :members:
   :show-inheritance:

creator
-------

.. automodule:: datadog_api_client.v2.model.creator
   :members:
   :show-inheritance:

dashboard\_list\_add\_items\_request
------------------------------------

.. automodule:: datadog_api_client.v2.model.dashboard_list_add_items_request
   :members:
   :show-inheritance:

dashboard\_list\_add\_items\_response
-------------------------------------

.. automodule:: datadog_api_client.v2.model.dashboard_list_add_items_response
   :members:
   :show-inheritance:

dashboard\_list\_delete\_items\_request
---------------------------------------

.. automodule:: datadog_api_client.v2.model.dashboard_list_delete_items_request
   :members:
   :show-inheritance:

dashboard\_list\_delete\_items\_response
----------------------------------------

.. automodule:: datadog_api_client.v2.model.dashboard_list_delete_items_response
   :members:
   :show-inheritance:

dashboard\_list\_item
---------------------

.. automodule:: datadog_api_client.v2.model.dashboard_list_item
   :members:
   :show-inheritance:

dashboard\_list\_item\_request
------------------------------

.. automodule:: datadog_api_client.v2.model.dashboard_list_item_request
   :members:
   :show-inheritance:

dashboard\_list\_item\_response
-------------------------------

.. automodule:: datadog_api_client.v2.model.dashboard_list_item_response
   :members:
   :show-inheritance:

dashboard\_list\_items
----------------------

.. automodule:: datadog_api_client.v2.model.dashboard_list_items
   :members:
   :show-inheritance:

dashboard\_list\_update\_items\_request
---------------------------------------

.. automodule:: datadog_api_client.v2.model.dashboard_list_update_items_request
   :members:
   :show-inheritance:

dashboard\_list\_update\_items\_response
----------------------------------------

.. automodule:: datadog_api_client.v2.model.dashboard_list_update_items_response
   :members:
   :show-inheritance:

dashboard\_type
---------------

.. automodule:: datadog_api_client.v2.model.dashboard_type
   :members:
   :show-inheritance:

event
-----

.. automodule:: datadog_api_client.v2.model.event
   :members:
   :show-inheritance:

event\_attributes
-----------------

.. automodule:: datadog_api_client.v2.model.event_attributes
   :members:
   :show-inheritance:

event\_priority
---------------

.. automodule:: datadog_api_client.v2.model.event_priority
   :members:
   :show-inheritance:

event\_response
---------------

.. automodule:: datadog_api_client.v2.model.event_response
   :members:
   :show-inheritance:

event\_response\_attributes
---------------------------

.. automodule:: datadog_api_client.v2.model.event_response_attributes
   :members:
   :show-inheritance:

event\_status\_type
-------------------

.. automodule:: datadog_api_client.v2.model.event_status_type
   :members:
   :show-inheritance:

event\_type
-----------

.. automodule:: datadog_api_client.v2.model.event_type
   :members:
   :show-inheritance:

events\_aggregation
-------------------

.. automodule:: datadog_api_client.v2.model.events_aggregation
   :members:
   :show-inheritance:

events\_compute
---------------

.. automodule:: datadog_api_client.v2.model.events_compute
   :members:
   :show-inheritance:

events\_data\_source
--------------------

.. automodule:: datadog_api_client.v2.model.events_data_source
   :members:
   :show-inheritance:

events\_group\_by
-----------------

.. automodule:: datadog_api_client.v2.model.events_group_by
   :members:
   :show-inheritance:

events\_group\_by\_sort
-----------------------

.. automodule:: datadog_api_client.v2.model.events_group_by_sort
   :members:
   :show-inheritance:

events\_list\_request
---------------------

.. automodule:: datadog_api_client.v2.model.events_list_request
   :members:
   :show-inheritance:

events\_list\_response
----------------------

.. automodule:: datadog_api_client.v2.model.events_list_response
   :members:
   :show-inheritance:

events\_list\_response\_links
-----------------------------

.. automodule:: datadog_api_client.v2.model.events_list_response_links
   :members:
   :show-inheritance:

events\_query\_filter
---------------------

.. automodule:: datadog_api_client.v2.model.events_query_filter
   :members:
   :show-inheritance:

events\_query\_group\_bys
-------------------------

.. automodule:: datadog_api_client.v2.model.events_query_group_bys
   :members:
   :show-inheritance:

events\_query\_options
----------------------

.. automodule:: datadog_api_client.v2.model.events_query_options
   :members:
   :show-inheritance:

events\_request\_page
---------------------

.. automodule:: datadog_api_client.v2.model.events_request_page
   :members:
   :show-inheritance:

events\_response\_metadata
--------------------------

.. automodule:: datadog_api_client.v2.model.events_response_metadata
   :members:
   :show-inheritance:

events\_response\_metadata\_page
--------------------------------

.. automodule:: datadog_api_client.v2.model.events_response_metadata_page
   :members:
   :show-inheritance:

events\_scalar\_query
---------------------

.. automodule:: datadog_api_client.v2.model.events_scalar_query
   :members:
   :show-inheritance:

events\_search
--------------

.. automodule:: datadog_api_client.v2.model.events_search
   :members:
   :show-inheritance:

events\_sort
------------

.. automodule:: datadog_api_client.v2.model.events_sort
   :members:
   :show-inheritance:

events\_sort\_type
------------------

.. automodule:: datadog_api_client.v2.model.events_sort_type
   :members:
   :show-inheritance:

events\_timeseries\_query
-------------------------

.. automodule:: datadog_api_client.v2.model.events_timeseries_query
   :members:
   :show-inheritance:

events\_warning
---------------

.. automodule:: datadog_api_client.v2.model.events_warning
   :members:
   :show-inheritance:

formula\_limit
--------------

.. automodule:: datadog_api_client.v2.model.formula_limit
   :members:
   :show-inheritance:

full\_api\_key
--------------

.. automodule:: datadog_api_client.v2.model.full_api_key
   :members:
   :show-inheritance:

full\_api\_key\_attributes
--------------------------

.. automodule:: datadog_api_client.v2.model.full_api_key_attributes
   :members:
   :show-inheritance:

full\_application\_key
----------------------

.. automodule:: datadog_api_client.v2.model.full_application_key
   :members:
   :show-inheritance:

full\_application\_key\_attributes
----------------------------------

.. automodule:: datadog_api_client.v2.model.full_application_key_attributes
   :members:
   :show-inheritance:

group\_tags
-----------

.. automodule:: datadog_api_client.v2.model.group_tags
   :members:
   :show-inheritance:

hourly\_usage
-------------

.. automodule:: datadog_api_client.v2.model.hourly_usage
   :members:
   :show-inheritance:

hourly\_usage\_attributes
-------------------------

.. automodule:: datadog_api_client.v2.model.hourly_usage_attributes
   :members:
   :show-inheritance:

hourly\_usage\_measurement
--------------------------

.. automodule:: datadog_api_client.v2.model.hourly_usage_measurement
   :members:
   :show-inheritance:

hourly\_usage\_metadata
-----------------------

.. automodule:: datadog_api_client.v2.model.hourly_usage_metadata
   :members:
   :show-inheritance:

hourly\_usage\_pagination
-------------------------

.. automodule:: datadog_api_client.v2.model.hourly_usage_pagination
   :members:
   :show-inheritance:

hourly\_usage\_response
-----------------------

.. automodule:: datadog_api_client.v2.model.hourly_usage_response
   :members:
   :show-inheritance:

hourly\_usage\_type
-------------------

.. automodule:: datadog_api_client.v2.model.hourly_usage_type
   :members:
   :show-inheritance:

http\_log
---------

.. automodule:: datadog_api_client.v2.model.http_log
   :members:
   :show-inheritance:

http\_log\_error
----------------

.. automodule:: datadog_api_client.v2.model.http_log_error
   :members:
   :show-inheritance:

http\_log\_errors
-----------------

.. automodule:: datadog_api_client.v2.model.http_log_errors
   :members:
   :show-inheritance:

http\_log\_item
---------------

.. automodule:: datadog_api_client.v2.model.http_log_item
   :members:
   :show-inheritance:

idp\_metadata\_form\_data
-------------------------

.. automodule:: datadog_api_client.v2.model.idp_metadata_form_data
   :members:
   :show-inheritance:

incident\_attachment\_attachment\_type
--------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_attachment_attachment_type
   :members:
   :show-inheritance:

incident\_attachment\_attributes
--------------------------------

.. automodule:: datadog_api_client.v2.model.incident_attachment_attributes
   :members:
   :show-inheritance:

incident\_attachment\_data
--------------------------

.. automodule:: datadog_api_client.v2.model.incident_attachment_data
   :members:
   :show-inheritance:

incident\_attachment\_link\_attachment\_type
--------------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_attachment_link_attachment_type
   :members:
   :show-inheritance:

incident\_attachment\_link\_attributes
--------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_attachment_link_attributes
   :members:
   :show-inheritance:

incident\_attachment\_link\_attributes\_attachment\_object
----------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_attachment_link_attributes_attachment_object
   :members:
   :show-inheritance:

incident\_attachment\_postmortem\_attachment\_type
--------------------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_attachment_postmortem_attachment_type
   :members:
   :show-inheritance:

incident\_attachment\_postmortem\_attributes
--------------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_attachment_postmortem_attributes
   :members:
   :show-inheritance:

incident\_attachment\_related\_object
-------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_attachment_related_object
   :members:
   :show-inheritance:

incident\_attachment\_relationships
-----------------------------------

.. automodule:: datadog_api_client.v2.model.incident_attachment_relationships
   :members:
   :show-inheritance:

incident\_attachment\_type
--------------------------

.. automodule:: datadog_api_client.v2.model.incident_attachment_type
   :members:
   :show-inheritance:

incident\_attachment\_update\_attributes
----------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_attachment_update_attributes
   :members:
   :show-inheritance:

incident\_attachment\_update\_data
----------------------------------

.. automodule:: datadog_api_client.v2.model.incident_attachment_update_data
   :members:
   :show-inheritance:

incident\_attachment\_update\_request
-------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_attachment_update_request
   :members:
   :show-inheritance:

incident\_attachment\_update\_response
--------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_attachment_update_response
   :members:
   :show-inheritance:

incident\_attachments\_postmortem\_attributes\_attachment\_object
-----------------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_attachments_postmortem_attributes_attachment_object
   :members:
   :show-inheritance:

incident\_attachments\_response
-------------------------------

.. automodule:: datadog_api_client.v2.model.incident_attachments_response
   :members:
   :show-inheritance:

incident\_attachments\_response\_included\_item
-----------------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_attachments_response_included_item
   :members:
   :show-inheritance:

incident\_create\_attributes
----------------------------

.. automodule:: datadog_api_client.v2.model.incident_create_attributes
   :members:
   :show-inheritance:

incident\_create\_data
----------------------

.. automodule:: datadog_api_client.v2.model.incident_create_data
   :members:
   :show-inheritance:

incident\_create\_relationships
-------------------------------

.. automodule:: datadog_api_client.v2.model.incident_create_relationships
   :members:
   :show-inheritance:

incident\_create\_request
-------------------------

.. automodule:: datadog_api_client.v2.model.incident_create_request
   :members:
   :show-inheritance:

incident\_field\_attributes
---------------------------

.. automodule:: datadog_api_client.v2.model.incident_field_attributes
   :members:
   :show-inheritance:

incident\_field\_attributes\_multiple\_value
--------------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_field_attributes_multiple_value
   :members:
   :show-inheritance:

incident\_field\_attributes\_single\_value
------------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_field_attributes_single_value
   :members:
   :show-inheritance:

incident\_field\_attributes\_single\_value\_type
------------------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_field_attributes_single_value_type
   :members:
   :show-inheritance:

incident\_field\_attributes\_value\_type
----------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_field_attributes_value_type
   :members:
   :show-inheritance:

incident\_integration\_metadata\_type
-------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_integration_metadata_type
   :members:
   :show-inheritance:

incident\_notification\_handle
------------------------------

.. automodule:: datadog_api_client.v2.model.incident_notification_handle
   :members:
   :show-inheritance:

incident\_postmortem\_type
--------------------------

.. automodule:: datadog_api_client.v2.model.incident_postmortem_type
   :members:
   :show-inheritance:

incident\_related\_object
-------------------------

.. automodule:: datadog_api_client.v2.model.incident_related_object
   :members:
   :show-inheritance:

incident\_response
------------------

.. automodule:: datadog_api_client.v2.model.incident_response
   :members:
   :show-inheritance:

incident\_response\_attributes
------------------------------

.. automodule:: datadog_api_client.v2.model.incident_response_attributes
   :members:
   :show-inheritance:

incident\_response\_data
------------------------

.. automodule:: datadog_api_client.v2.model.incident_response_data
   :members:
   :show-inheritance:

incident\_response\_included\_item
----------------------------------

.. automodule:: datadog_api_client.v2.model.incident_response_included_item
   :members:
   :show-inheritance:

incident\_response\_meta
------------------------

.. automodule:: datadog_api_client.v2.model.incident_response_meta
   :members:
   :show-inheritance:

incident\_response\_meta\_pagination
------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_response_meta_pagination
   :members:
   :show-inheritance:

incident\_response\_relationships
---------------------------------

.. automodule:: datadog_api_client.v2.model.incident_response_relationships
   :members:
   :show-inheritance:

incident\_service\_create\_attributes
-------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_service_create_attributes
   :members:
   :show-inheritance:

incident\_service\_create\_data
-------------------------------

.. automodule:: datadog_api_client.v2.model.incident_service_create_data
   :members:
   :show-inheritance:

incident\_service\_create\_request
----------------------------------

.. automodule:: datadog_api_client.v2.model.incident_service_create_request
   :members:
   :show-inheritance:

incident\_service\_included\_items
----------------------------------

.. automodule:: datadog_api_client.v2.model.incident_service_included_items
   :members:
   :show-inheritance:

incident\_service\_relationships
--------------------------------

.. automodule:: datadog_api_client.v2.model.incident_service_relationships
   :members:
   :show-inheritance:

incident\_service\_response
---------------------------

.. automodule:: datadog_api_client.v2.model.incident_service_response
   :members:
   :show-inheritance:

incident\_service\_response\_attributes
---------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_service_response_attributes
   :members:
   :show-inheritance:

incident\_service\_response\_data
---------------------------------

.. automodule:: datadog_api_client.v2.model.incident_service_response_data
   :members:
   :show-inheritance:

incident\_service\_type
-----------------------

.. automodule:: datadog_api_client.v2.model.incident_service_type
   :members:
   :show-inheritance:

incident\_service\_update\_attributes
-------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_service_update_attributes
   :members:
   :show-inheritance:

incident\_service\_update\_data
-------------------------------

.. automodule:: datadog_api_client.v2.model.incident_service_update_data
   :members:
   :show-inheritance:

incident\_service\_update\_request
----------------------------------

.. automodule:: datadog_api_client.v2.model.incident_service_update_request
   :members:
   :show-inheritance:

incident\_services\_response
----------------------------

.. automodule:: datadog_api_client.v2.model.incident_services_response
   :members:
   :show-inheritance:

incident\_team\_create\_attributes
----------------------------------

.. automodule:: datadog_api_client.v2.model.incident_team_create_attributes
   :members:
   :show-inheritance:

incident\_team\_create\_data
----------------------------

.. automodule:: datadog_api_client.v2.model.incident_team_create_data
   :members:
   :show-inheritance:

incident\_team\_create\_request
-------------------------------

.. automodule:: datadog_api_client.v2.model.incident_team_create_request
   :members:
   :show-inheritance:

incident\_team\_included\_items
-------------------------------

.. automodule:: datadog_api_client.v2.model.incident_team_included_items
   :members:
   :show-inheritance:

incident\_team\_relationships
-----------------------------

.. automodule:: datadog_api_client.v2.model.incident_team_relationships
   :members:
   :show-inheritance:

incident\_team\_response
------------------------

.. automodule:: datadog_api_client.v2.model.incident_team_response
   :members:
   :show-inheritance:

incident\_team\_response\_attributes
------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_team_response_attributes
   :members:
   :show-inheritance:

incident\_team\_response\_data
------------------------------

.. automodule:: datadog_api_client.v2.model.incident_team_response_data
   :members:
   :show-inheritance:

incident\_team\_type
--------------------

.. automodule:: datadog_api_client.v2.model.incident_team_type
   :members:
   :show-inheritance:

incident\_team\_update\_attributes
----------------------------------

.. automodule:: datadog_api_client.v2.model.incident_team_update_attributes
   :members:
   :show-inheritance:

incident\_team\_update\_data
----------------------------

.. automodule:: datadog_api_client.v2.model.incident_team_update_data
   :members:
   :show-inheritance:

incident\_team\_update\_request
-------------------------------

.. automodule:: datadog_api_client.v2.model.incident_team_update_request
   :members:
   :show-inheritance:

incident\_teams\_response
-------------------------

.. automodule:: datadog_api_client.v2.model.incident_teams_response
   :members:
   :show-inheritance:

incident\_timeline\_cell\_create\_attributes
--------------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_timeline_cell_create_attributes
   :members:
   :show-inheritance:

incident\_timeline\_cell\_markdown\_content\_type
-------------------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_timeline_cell_markdown_content_type
   :members:
   :show-inheritance:

incident\_timeline\_cell\_markdown\_create\_attributes
------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_timeline_cell_markdown_create_attributes
   :members:
   :show-inheritance:

incident\_timeline\_cell\_markdown\_create\_attributes\_content
---------------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.incident_timeline_cell_markdown_create_attributes_content
   :members:
   :show-inheritance:

incident\_type
--------------

.. automodule:: datadog_api_client.v2.model.incident_type
   :members:
   :show-inheritance:

incident\_update\_attributes
----------------------------

.. automodule:: datadog_api_client.v2.model.incident_update_attributes
   :members:
   :show-inheritance:

incident\_update\_data
----------------------

.. automodule:: datadog_api_client.v2.model.incident_update_data
   :members:
   :show-inheritance:

incident\_update\_relationships
-------------------------------

.. automodule:: datadog_api_client.v2.model.incident_update_relationships
   :members:
   :show-inheritance:

incident\_update\_request
-------------------------

.. automodule:: datadog_api_client.v2.model.incident_update_request
   :members:
   :show-inheritance:

incidents\_response
-------------------

.. automodule:: datadog_api_client.v2.model.incidents_response
   :members:
   :show-inheritance:

intake\_payload\_accepted
-------------------------

.. automodule:: datadog_api_client.v2.model.intake_payload_accepted
   :members:
   :show-inheritance:

list\_application\_keys\_response
---------------------------------

.. automodule:: datadog_api_client.v2.model.list_application_keys_response
   :members:
   :show-inheritance:

log
---

.. automodule:: datadog_api_client.v2.model.log
   :members:
   :show-inheritance:

log\_attributes
---------------

.. automodule:: datadog_api_client.v2.model.log_attributes
   :members:
   :show-inheritance:

log\_type
---------

.. automodule:: datadog_api_client.v2.model.log_type
   :members:
   :show-inheritance:

logs\_aggregate\_bucket
-----------------------

.. automodule:: datadog_api_client.v2.model.logs_aggregate_bucket
   :members:
   :show-inheritance:

logs\_aggregate\_bucket\_value
------------------------------

.. automodule:: datadog_api_client.v2.model.logs_aggregate_bucket_value
   :members:
   :show-inheritance:

logs\_aggregate\_bucket\_value\_timeseries
------------------------------------------

.. automodule:: datadog_api_client.v2.model.logs_aggregate_bucket_value_timeseries
   :members:
   :show-inheritance:

logs\_aggregate\_bucket\_value\_timeseries\_point
-------------------------------------------------

.. automodule:: datadog_api_client.v2.model.logs_aggregate_bucket_value_timeseries_point
   :members:
   :show-inheritance:

logs\_aggregate\_request
------------------------

.. automodule:: datadog_api_client.v2.model.logs_aggregate_request
   :members:
   :show-inheritance:

logs\_aggregate\_request\_page
------------------------------

.. automodule:: datadog_api_client.v2.model.logs_aggregate_request_page
   :members:
   :show-inheritance:

logs\_aggregate\_response
-------------------------

.. automodule:: datadog_api_client.v2.model.logs_aggregate_response
   :members:
   :show-inheritance:

logs\_aggregate\_response\_data
-------------------------------

.. automodule:: datadog_api_client.v2.model.logs_aggregate_response_data
   :members:
   :show-inheritance:

logs\_aggregate\_response\_status
---------------------------------

.. automodule:: datadog_api_client.v2.model.logs_aggregate_response_status
   :members:
   :show-inheritance:

logs\_aggregate\_sort
---------------------

.. automodule:: datadog_api_client.v2.model.logs_aggregate_sort
   :members:
   :show-inheritance:

logs\_aggregate\_sort\_type
---------------------------

.. automodule:: datadog_api_client.v2.model.logs_aggregate_sort_type
   :members:
   :show-inheritance:

logs\_aggregation\_function
---------------------------

.. automodule:: datadog_api_client.v2.model.logs_aggregation_function
   :members:
   :show-inheritance:

logs\_archive
-------------

.. automodule:: datadog_api_client.v2.model.logs_archive
   :members:
   :show-inheritance:

logs\_archive\_attributes
-------------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_attributes
   :members:
   :show-inheritance:

logs\_archive\_create\_request
------------------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_create_request
   :members:
   :show-inheritance:

logs\_archive\_create\_request\_attributes
------------------------------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_create_request_attributes
   :members:
   :show-inheritance:

logs\_archive\_create\_request\_definition
------------------------------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_create_request_definition
   :members:
   :show-inheritance:

logs\_archive\_create\_request\_destination
-------------------------------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_create_request_destination
   :members:
   :show-inheritance:

logs\_archive\_definition
-------------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_definition
   :members:
   :show-inheritance:

logs\_archive\_destination
--------------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_destination
   :members:
   :show-inheritance:

logs\_archive\_destination\_azure
---------------------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_destination_azure
   :members:
   :show-inheritance:

logs\_archive\_destination\_azure\_type
---------------------------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_destination_azure_type
   :members:
   :show-inheritance:

logs\_archive\_destination\_gcs
-------------------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_destination_gcs
   :members:
   :show-inheritance:

logs\_archive\_destination\_gcs\_type
-------------------------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_destination_gcs_type
   :members:
   :show-inheritance:

logs\_archive\_destination\_s3
------------------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_destination_s3
   :members:
   :show-inheritance:

logs\_archive\_destination\_s3\_type
------------------------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_destination_s3_type
   :members:
   :show-inheritance:

logs\_archive\_integration\_azure
---------------------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_integration_azure
   :members:
   :show-inheritance:

logs\_archive\_integration\_gcs
-------------------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_integration_gcs
   :members:
   :show-inheritance:

logs\_archive\_integration\_s3
------------------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_integration_s3
   :members:
   :show-inheritance:

logs\_archive\_order
--------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_order
   :members:
   :show-inheritance:

logs\_archive\_order\_attributes
--------------------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_order_attributes
   :members:
   :show-inheritance:

logs\_archive\_order\_definition
--------------------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_order_definition
   :members:
   :show-inheritance:

logs\_archive\_order\_definition\_type
--------------------------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_order_definition_type
   :members:
   :show-inheritance:

logs\_archive\_state
--------------------

.. automodule:: datadog_api_client.v2.model.logs_archive_state
   :members:
   :show-inheritance:

logs\_archives
--------------

.. automodule:: datadog_api_client.v2.model.logs_archives
   :members:
   :show-inheritance:

logs\_compute
-------------

.. automodule:: datadog_api_client.v2.model.logs_compute
   :members:
   :show-inheritance:

logs\_compute\_type
-------------------

.. automodule:: datadog_api_client.v2.model.logs_compute_type
   :members:
   :show-inheritance:

logs\_group\_by
---------------

.. automodule:: datadog_api_client.v2.model.logs_group_by
   :members:
   :show-inheritance:

logs\_group\_by\_histogram
--------------------------

.. automodule:: datadog_api_client.v2.model.logs_group_by_histogram
   :members:
   :show-inheritance:

logs\_group\_by\_missing
------------------------

.. automodule:: datadog_api_client.v2.model.logs_group_by_missing
   :members:
   :show-inheritance:

logs\_group\_by\_total
----------------------

.. automodule:: datadog_api_client.v2.model.logs_group_by_total
   :members:
   :show-inheritance:

logs\_list\_request
-------------------

.. automodule:: datadog_api_client.v2.model.logs_list_request
   :members:
   :show-inheritance:

logs\_list\_request\_page
-------------------------

.. automodule:: datadog_api_client.v2.model.logs_list_request_page
   :members:
   :show-inheritance:

logs\_list\_response
--------------------

.. automodule:: datadog_api_client.v2.model.logs_list_response
   :members:
   :show-inheritance:

logs\_list\_response\_links
---------------------------

.. automodule:: datadog_api_client.v2.model.logs_list_response_links
   :members:
   :show-inheritance:

logs\_metric\_compute
---------------------

.. automodule:: datadog_api_client.v2.model.logs_metric_compute
   :members:
   :show-inheritance:

logs\_metric\_compute\_aggregation\_type
----------------------------------------

.. automodule:: datadog_api_client.v2.model.logs_metric_compute_aggregation_type
   :members:
   :show-inheritance:

logs\_metric\_create\_attributes
--------------------------------

.. automodule:: datadog_api_client.v2.model.logs_metric_create_attributes
   :members:
   :show-inheritance:

logs\_metric\_create\_data
--------------------------

.. automodule:: datadog_api_client.v2.model.logs_metric_create_data
   :members:
   :show-inheritance:

logs\_metric\_create\_request
-----------------------------

.. automodule:: datadog_api_client.v2.model.logs_metric_create_request
   :members:
   :show-inheritance:

logs\_metric\_filter
--------------------

.. automodule:: datadog_api_client.v2.model.logs_metric_filter
   :members:
   :show-inheritance:

logs\_metric\_group\_by
-----------------------

.. automodule:: datadog_api_client.v2.model.logs_metric_group_by
   :members:
   :show-inheritance:

logs\_metric\_response
----------------------

.. automodule:: datadog_api_client.v2.model.logs_metric_response
   :members:
   :show-inheritance:

logs\_metric\_response\_attributes
----------------------------------

.. automodule:: datadog_api_client.v2.model.logs_metric_response_attributes
   :members:
   :show-inheritance:

logs\_metric\_response\_compute
-------------------------------

.. automodule:: datadog_api_client.v2.model.logs_metric_response_compute
   :members:
   :show-inheritance:

logs\_metric\_response\_compute\_aggregation\_type
--------------------------------------------------

.. automodule:: datadog_api_client.v2.model.logs_metric_response_compute_aggregation_type
   :members:
   :show-inheritance:

logs\_metric\_response\_data
----------------------------

.. automodule:: datadog_api_client.v2.model.logs_metric_response_data
   :members:
   :show-inheritance:

logs\_metric\_response\_filter
------------------------------

.. automodule:: datadog_api_client.v2.model.logs_metric_response_filter
   :members:
   :show-inheritance:

logs\_metric\_response\_group\_by
---------------------------------

.. automodule:: datadog_api_client.v2.model.logs_metric_response_group_by
   :members:
   :show-inheritance:

logs\_metric\_type
------------------

.. automodule:: datadog_api_client.v2.model.logs_metric_type
   :members:
   :show-inheritance:

logs\_metric\_update\_attributes
--------------------------------

.. automodule:: datadog_api_client.v2.model.logs_metric_update_attributes
   :members:
   :show-inheritance:

logs\_metric\_update\_compute
-----------------------------

.. automodule:: datadog_api_client.v2.model.logs_metric_update_compute
   :members:
   :show-inheritance:

logs\_metric\_update\_data
--------------------------

.. automodule:: datadog_api_client.v2.model.logs_metric_update_data
   :members:
   :show-inheritance:

logs\_metric\_update\_request
-----------------------------

.. automodule:: datadog_api_client.v2.model.logs_metric_update_request
   :members:
   :show-inheritance:

logs\_metrics\_response
-----------------------

.. automodule:: datadog_api_client.v2.model.logs_metrics_response
   :members:
   :show-inheritance:

logs\_query\_filter
-------------------

.. automodule:: datadog_api_client.v2.model.logs_query_filter
   :members:
   :show-inheritance:

logs\_query\_options
--------------------

.. automodule:: datadog_api_client.v2.model.logs_query_options
   :members:
   :show-inheritance:

logs\_response\_metadata
------------------------

.. automodule:: datadog_api_client.v2.model.logs_response_metadata
   :members:
   :show-inheritance:

logs\_response\_metadata\_page
------------------------------

.. automodule:: datadog_api_client.v2.model.logs_response_metadata_page
   :members:
   :show-inheritance:

logs\_sort
----------

.. automodule:: datadog_api_client.v2.model.logs_sort
   :members:
   :show-inheritance:

logs\_sort\_order
-----------------

.. automodule:: datadog_api_client.v2.model.logs_sort_order
   :members:
   :show-inheritance:

logs\_storage\_tier
-------------------

.. automodule:: datadog_api_client.v2.model.logs_storage_tier
   :members:
   :show-inheritance:

logs\_warning
-------------

.. automodule:: datadog_api_client.v2.model.logs_warning
   :members:
   :show-inheritance:

metric
------

.. automodule:: datadog_api_client.v2.model.metric
   :members:
   :show-inheritance:

metric\_active\_configuration\_type
-----------------------------------

.. automodule:: datadog_api_client.v2.model.metric_active_configuration_type
   :members:
   :show-inheritance:

metric\_all\_tags
-----------------

.. automodule:: datadog_api_client.v2.model.metric_all_tags
   :members:
   :show-inheritance:

metric\_all\_tags\_attributes
-----------------------------

.. automodule:: datadog_api_client.v2.model.metric_all_tags_attributes
   :members:
   :show-inheritance:

metric\_all\_tags\_response
---------------------------

.. automodule:: datadog_api_client.v2.model.metric_all_tags_response
   :members:
   :show-inheritance:

metric\_bulk\_configure\_tags\_type
-----------------------------------

.. automodule:: datadog_api_client.v2.model.metric_bulk_configure_tags_type
   :members:
   :show-inheritance:

metric\_bulk\_tag\_config\_create
---------------------------------

.. automodule:: datadog_api_client.v2.model.metric_bulk_tag_config_create
   :members:
   :show-inheritance:

metric\_bulk\_tag\_config\_create\_attributes
---------------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_bulk_tag_config_create_attributes
   :members:
   :show-inheritance:

metric\_bulk\_tag\_config\_create\_request
------------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_bulk_tag_config_create_request
   :members:
   :show-inheritance:

metric\_bulk\_tag\_config\_delete
---------------------------------

.. automodule:: datadog_api_client.v2.model.metric_bulk_tag_config_delete
   :members:
   :show-inheritance:

metric\_bulk\_tag\_config\_delete\_attributes
---------------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_bulk_tag_config_delete_attributes
   :members:
   :show-inheritance:

metric\_bulk\_tag\_config\_delete\_request
------------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_bulk_tag_config_delete_request
   :members:
   :show-inheritance:

metric\_bulk\_tag\_config\_email\_list
--------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_bulk_tag_config_email_list
   :members:
   :show-inheritance:

metric\_bulk\_tag\_config\_response
-----------------------------------

.. automodule:: datadog_api_client.v2.model.metric_bulk_tag_config_response
   :members:
   :show-inheritance:

metric\_bulk\_tag\_config\_status
---------------------------------

.. automodule:: datadog_api_client.v2.model.metric_bulk_tag_config_status
   :members:
   :show-inheritance:

metric\_bulk\_tag\_config\_status\_attributes
---------------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_bulk_tag_config_status_attributes
   :members:
   :show-inheritance:

metric\_bulk\_tag\_config\_tag\_name\_list
------------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_bulk_tag_config_tag_name_list
   :members:
   :show-inheritance:

metric\_content\_encoding
-------------------------

.. automodule:: datadog_api_client.v2.model.metric_content_encoding
   :members:
   :show-inheritance:

metric\_custom\_aggregation
---------------------------

.. automodule:: datadog_api_client.v2.model.metric_custom_aggregation
   :members:
   :show-inheritance:

metric\_custom\_aggregations
----------------------------

.. automodule:: datadog_api_client.v2.model.metric_custom_aggregations
   :members:
   :show-inheritance:

metric\_custom\_space\_aggregation
----------------------------------

.. automodule:: datadog_api_client.v2.model.metric_custom_space_aggregation
   :members:
   :show-inheritance:

metric\_custom\_time\_aggregation
---------------------------------

.. automodule:: datadog_api_client.v2.model.metric_custom_time_aggregation
   :members:
   :show-inheritance:

metric\_distinct\_volume
------------------------

.. automodule:: datadog_api_client.v2.model.metric_distinct_volume
   :members:
   :show-inheritance:

metric\_distinct\_volume\_attributes
------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_distinct_volume_attributes
   :members:
   :show-inheritance:

metric\_distinct\_volume\_type
------------------------------

.. automodule:: datadog_api_client.v2.model.metric_distinct_volume_type
   :members:
   :show-inheritance:

metric\_estimate
----------------

.. automodule:: datadog_api_client.v2.model.metric_estimate
   :members:
   :show-inheritance:

metric\_estimate\_attributes
----------------------------

.. automodule:: datadog_api_client.v2.model.metric_estimate_attributes
   :members:
   :show-inheritance:

metric\_estimate\_resource\_type
--------------------------------

.. automodule:: datadog_api_client.v2.model.metric_estimate_resource_type
   :members:
   :show-inheritance:

metric\_estimate\_response
--------------------------

.. automodule:: datadog_api_client.v2.model.metric_estimate_response
   :members:
   :show-inheritance:

metric\_estimate\_type
----------------------

.. automodule:: datadog_api_client.v2.model.metric_estimate_type
   :members:
   :show-inheritance:

metric\_ingested\_indexed\_volume
---------------------------------

.. automodule:: datadog_api_client.v2.model.metric_ingested_indexed_volume
   :members:
   :show-inheritance:

metric\_ingested\_indexed\_volume\_attributes
---------------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_ingested_indexed_volume_attributes
   :members:
   :show-inheritance:

metric\_ingested\_indexed\_volume\_type
---------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_ingested_indexed_volume_type
   :members:
   :show-inheritance:

metric\_intake\_type
--------------------

.. automodule:: datadog_api_client.v2.model.metric_intake_type
   :members:
   :show-inheritance:

metric\_metadata
----------------

.. automodule:: datadog_api_client.v2.model.metric_metadata
   :members:
   :show-inheritance:

metric\_origin
--------------

.. automodule:: datadog_api_client.v2.model.metric_origin
   :members:
   :show-inheritance:

metric\_payload
---------------

.. automodule:: datadog_api_client.v2.model.metric_payload
   :members:
   :show-inheritance:

metric\_point
-------------

.. automodule:: datadog_api_client.v2.model.metric_point
   :members:
   :show-inheritance:

metric\_resource
----------------

.. automodule:: datadog_api_client.v2.model.metric_resource
   :members:
   :show-inheritance:

metric\_series
--------------

.. automodule:: datadog_api_client.v2.model.metric_series
   :members:
   :show-inheritance:

metric\_suggested\_aggregations
-------------------------------

.. automodule:: datadog_api_client.v2.model.metric_suggested_aggregations
   :members:
   :show-inheritance:

metric\_suggested\_tags\_and\_aggregations
------------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_suggested_tags_and_aggregations
   :members:
   :show-inheritance:

metric\_suggested\_tags\_and\_aggregations\_response
----------------------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_suggested_tags_and_aggregations_response
   :members:
   :show-inheritance:

metric\_suggested\_tags\_attributes
-----------------------------------

.. automodule:: datadog_api_client.v2.model.metric_suggested_tags_attributes
   :members:
   :show-inheritance:

metric\_tag\_configuration
--------------------------

.. automodule:: datadog_api_client.v2.model.metric_tag_configuration
   :members:
   :show-inheritance:

metric\_tag\_configuration\_attributes
--------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_tag_configuration_attributes
   :members:
   :show-inheritance:

metric\_tag\_configuration\_create\_attributes
----------------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_tag_configuration_create_attributes
   :members:
   :show-inheritance:

metric\_tag\_configuration\_create\_data
----------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_tag_configuration_create_data
   :members:
   :show-inheritance:

metric\_tag\_configuration\_create\_request
-------------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_tag_configuration_create_request
   :members:
   :show-inheritance:

metric\_tag\_configuration\_metric\_types
-----------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_tag_configuration_metric_types
   :members:
   :show-inheritance:

metric\_tag\_configuration\_response
------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_tag_configuration_response
   :members:
   :show-inheritance:

metric\_tag\_configuration\_type
--------------------------------

.. automodule:: datadog_api_client.v2.model.metric_tag_configuration_type
   :members:
   :show-inheritance:

metric\_tag\_configuration\_update\_attributes
----------------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_tag_configuration_update_attributes
   :members:
   :show-inheritance:

metric\_tag\_configuration\_update\_data
----------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_tag_configuration_update_data
   :members:
   :show-inheritance:

metric\_tag\_configuration\_update\_request
-------------------------------------------

.. automodule:: datadog_api_client.v2.model.metric_tag_configuration_update_request
   :members:
   :show-inheritance:

metric\_type
------------

.. automodule:: datadog_api_client.v2.model.metric_type
   :members:
   :show-inheritance:

metric\_volumes
---------------

.. automodule:: datadog_api_client.v2.model.metric_volumes
   :members:
   :show-inheritance:

metric\_volumes\_response
-------------------------

.. automodule:: datadog_api_client.v2.model.metric_volumes_response
   :members:
   :show-inheritance:

metrics\_aggregator
-------------------

.. automodule:: datadog_api_client.v2.model.metrics_aggregator
   :members:
   :show-inheritance:

metrics\_and\_metric\_tag\_configurations
-----------------------------------------

.. automodule:: datadog_api_client.v2.model.metrics_and_metric_tag_configurations
   :members:
   :show-inheritance:

metrics\_and\_metric\_tag\_configurations\_response
---------------------------------------------------

.. automodule:: datadog_api_client.v2.model.metrics_and_metric_tag_configurations_response
   :members:
   :show-inheritance:

metrics\_data\_source
---------------------

.. automodule:: datadog_api_client.v2.model.metrics_data_source
   :members:
   :show-inheritance:

metrics\_scalar\_query
----------------------

.. automodule:: datadog_api_client.v2.model.metrics_scalar_query
   :members:
   :show-inheritance:

metrics\_timeseries\_query
--------------------------

.. automodule:: datadog_api_client.v2.model.metrics_timeseries_query
   :members:
   :show-inheritance:

monitor\_type
-------------

.. automodule:: datadog_api_client.v2.model.monitor_type
   :members:
   :show-inheritance:

nullable\_relationship\_to\_user
--------------------------------

.. automodule:: datadog_api_client.v2.model.nullable_relationship_to_user
   :members:
   :show-inheritance:

nullable\_relationship\_to\_user\_data
--------------------------------------

.. automodule:: datadog_api_client.v2.model.nullable_relationship_to_user_data
   :members:
   :show-inheritance:

opsgenie\_service\_create\_attributes
-------------------------------------

.. automodule:: datadog_api_client.v2.model.opsgenie_service_create_attributes
   :members:
   :show-inheritance:

opsgenie\_service\_create\_data
-------------------------------

.. automodule:: datadog_api_client.v2.model.opsgenie_service_create_data
   :members:
   :show-inheritance:

opsgenie\_service\_create\_request
----------------------------------

.. automodule:: datadog_api_client.v2.model.opsgenie_service_create_request
   :members:
   :show-inheritance:

opsgenie\_service\_region\_type
-------------------------------

.. automodule:: datadog_api_client.v2.model.opsgenie_service_region_type
   :members:
   :show-inheritance:

opsgenie\_service\_response
---------------------------

.. automodule:: datadog_api_client.v2.model.opsgenie_service_response
   :members:
   :show-inheritance:

opsgenie\_service\_response\_attributes
---------------------------------------

.. automodule:: datadog_api_client.v2.model.opsgenie_service_response_attributes
   :members:
   :show-inheritance:

opsgenie\_service\_response\_data
---------------------------------

.. automodule:: datadog_api_client.v2.model.opsgenie_service_response_data
   :members:
   :show-inheritance:

opsgenie\_service\_type
-----------------------

.. automodule:: datadog_api_client.v2.model.opsgenie_service_type
   :members:
   :show-inheritance:

opsgenie\_service\_update\_attributes
-------------------------------------

.. automodule:: datadog_api_client.v2.model.opsgenie_service_update_attributes
   :members:
   :show-inheritance:

opsgenie\_service\_update\_data
-------------------------------

.. automodule:: datadog_api_client.v2.model.opsgenie_service_update_data
   :members:
   :show-inheritance:

opsgenie\_service\_update\_request
----------------------------------

.. automodule:: datadog_api_client.v2.model.opsgenie_service_update_request
   :members:
   :show-inheritance:

opsgenie\_services\_response
----------------------------

.. automodule:: datadog_api_client.v2.model.opsgenie_services_response
   :members:
   :show-inheritance:

organization
------------

.. automodule:: datadog_api_client.v2.model.organization
   :members:
   :show-inheritance:

organization\_attributes
------------------------

.. automodule:: datadog_api_client.v2.model.organization_attributes
   :members:
   :show-inheritance:

organizations\_type
-------------------

.. automodule:: datadog_api_client.v2.model.organizations_type
   :members:
   :show-inheritance:

pagination
----------

.. automodule:: datadog_api_client.v2.model.pagination
   :members:
   :show-inheritance:

partial\_api\_key
-----------------

.. automodule:: datadog_api_client.v2.model.partial_api_key
   :members:
   :show-inheritance:

partial\_api\_key\_attributes
-----------------------------

.. automodule:: datadog_api_client.v2.model.partial_api_key_attributes
   :members:
   :show-inheritance:

partial\_application\_key
-------------------------

.. automodule:: datadog_api_client.v2.model.partial_application_key
   :members:
   :show-inheritance:

partial\_application\_key\_attributes
-------------------------------------

.. automodule:: datadog_api_client.v2.model.partial_application_key_attributes
   :members:
   :show-inheritance:

partial\_application\_key\_response
-----------------------------------

.. automodule:: datadog_api_client.v2.model.partial_application_key_response
   :members:
   :show-inheritance:

permission
----------

.. automodule:: datadog_api_client.v2.model.permission
   :members:
   :show-inheritance:

permission\_attributes
----------------------

.. automodule:: datadog_api_client.v2.model.permission_attributes
   :members:
   :show-inheritance:

permissions\_response
---------------------

.. automodule:: datadog_api_client.v2.model.permissions_response
   :members:
   :show-inheritance:

permissions\_type
-----------------

.. automodule:: datadog_api_client.v2.model.permissions_type
   :members:
   :show-inheritance:

process\_summaries\_meta
------------------------

.. automodule:: datadog_api_client.v2.model.process_summaries_meta
   :members:
   :show-inheritance:

process\_summaries\_meta\_page
------------------------------

.. automodule:: datadog_api_client.v2.model.process_summaries_meta_page
   :members:
   :show-inheritance:

process\_summaries\_response
----------------------------

.. automodule:: datadog_api_client.v2.model.process_summaries_response
   :members:
   :show-inheritance:

process\_summary
----------------

.. automodule:: datadog_api_client.v2.model.process_summary
   :members:
   :show-inheritance:

process\_summary\_attributes
----------------------------

.. automodule:: datadog_api_client.v2.model.process_summary_attributes
   :members:
   :show-inheritance:

process\_summary\_type
----------------------

.. automodule:: datadog_api_client.v2.model.process_summary_type
   :members:
   :show-inheritance:

query\_formula
--------------

.. automodule:: datadog_api_client.v2.model.query_formula
   :members:
   :show-inheritance:

query\_sort\_order
------------------

.. automodule:: datadog_api_client.v2.model.query_sort_order
   :members:
   :show-inheritance:

relationship\_to\_incident\_attachment
--------------------------------------

.. automodule:: datadog_api_client.v2.model.relationship_to_incident_attachment
   :members:
   :show-inheritance:

relationship\_to\_incident\_attachment\_data
--------------------------------------------

.. automodule:: datadog_api_client.v2.model.relationship_to_incident_attachment_data
   :members:
   :show-inheritance:

relationship\_to\_incident\_integration\_metadata\_data
-------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.relationship_to_incident_integration_metadata_data
   :members:
   :show-inheritance:

relationship\_to\_incident\_integration\_metadatas
--------------------------------------------------

.. automodule:: datadog_api_client.v2.model.relationship_to_incident_integration_metadatas
   :members:
   :show-inheritance:

relationship\_to\_incident\_postmortem
--------------------------------------

.. automodule:: datadog_api_client.v2.model.relationship_to_incident_postmortem
   :members:
   :show-inheritance:

relationship\_to\_incident\_postmortem\_data
--------------------------------------------

.. automodule:: datadog_api_client.v2.model.relationship_to_incident_postmortem_data
   :members:
   :show-inheritance:

relationship\_to\_organization
------------------------------

.. automodule:: datadog_api_client.v2.model.relationship_to_organization
   :members:
   :show-inheritance:

relationship\_to\_organization\_data
------------------------------------

.. automodule:: datadog_api_client.v2.model.relationship_to_organization_data
   :members:
   :show-inheritance:

relationship\_to\_organizations
-------------------------------

.. automodule:: datadog_api_client.v2.model.relationship_to_organizations
   :members:
   :show-inheritance:

relationship\_to\_permission
----------------------------

.. automodule:: datadog_api_client.v2.model.relationship_to_permission
   :members:
   :show-inheritance:

relationship\_to\_permission\_data
----------------------------------

.. automodule:: datadog_api_client.v2.model.relationship_to_permission_data
   :members:
   :show-inheritance:

relationship\_to\_permissions
-----------------------------

.. automodule:: datadog_api_client.v2.model.relationship_to_permissions
   :members:
   :show-inheritance:

relationship\_to\_role
----------------------

.. automodule:: datadog_api_client.v2.model.relationship_to_role
   :members:
   :show-inheritance:

relationship\_to\_role\_data
----------------------------

.. automodule:: datadog_api_client.v2.model.relationship_to_role_data
   :members:
   :show-inheritance:

relationship\_to\_roles
-----------------------

.. automodule:: datadog_api_client.v2.model.relationship_to_roles
   :members:
   :show-inheritance:

relationship\_to\_saml\_assertion\_attribute
--------------------------------------------

.. automodule:: datadog_api_client.v2.model.relationship_to_saml_assertion_attribute
   :members:
   :show-inheritance:

relationship\_to\_saml\_assertion\_attribute\_data
--------------------------------------------------

.. automodule:: datadog_api_client.v2.model.relationship_to_saml_assertion_attribute_data
   :members:
   :show-inheritance:

relationship\_to\_user
----------------------

.. automodule:: datadog_api_client.v2.model.relationship_to_user
   :members:
   :show-inheritance:

relationship\_to\_user\_data
----------------------------

.. automodule:: datadog_api_client.v2.model.relationship_to_user_data
   :members:
   :show-inheritance:

relationship\_to\_users
-----------------------

.. automodule:: datadog_api_client.v2.model.relationship_to_users
   :members:
   :show-inheritance:

response\_meta\_attributes
--------------------------

.. automodule:: datadog_api_client.v2.model.response_meta_attributes
   :members:
   :show-inheritance:

role
----

.. automodule:: datadog_api_client.v2.model.role
   :members:
   :show-inheritance:

role\_attributes
----------------

.. automodule:: datadog_api_client.v2.model.role_attributes
   :members:
   :show-inheritance:

role\_clone
-----------

.. automodule:: datadog_api_client.v2.model.role_clone
   :members:
   :show-inheritance:

role\_clone\_attributes
-----------------------

.. automodule:: datadog_api_client.v2.model.role_clone_attributes
   :members:
   :show-inheritance:

role\_clone\_request
--------------------

.. automodule:: datadog_api_client.v2.model.role_clone_request
   :members:
   :show-inheritance:

role\_create\_attributes
------------------------

.. automodule:: datadog_api_client.v2.model.role_create_attributes
   :members:
   :show-inheritance:

role\_create\_data
------------------

.. automodule:: datadog_api_client.v2.model.role_create_data
   :members:
   :show-inheritance:

role\_create\_request
---------------------

.. automodule:: datadog_api_client.v2.model.role_create_request
   :members:
   :show-inheritance:

role\_create\_response
----------------------

.. automodule:: datadog_api_client.v2.model.role_create_response
   :members:
   :show-inheritance:

role\_create\_response\_data
----------------------------

.. automodule:: datadog_api_client.v2.model.role_create_response_data
   :members:
   :show-inheritance:

role\_relationships
-------------------

.. automodule:: datadog_api_client.v2.model.role_relationships
   :members:
   :show-inheritance:

role\_response
--------------

.. automodule:: datadog_api_client.v2.model.role_response
   :members:
   :show-inheritance:

role\_response\_relationships
-----------------------------

.. automodule:: datadog_api_client.v2.model.role_response_relationships
   :members:
   :show-inheritance:

role\_update\_attributes
------------------------

.. automodule:: datadog_api_client.v2.model.role_update_attributes
   :members:
   :show-inheritance:

role\_update\_data
------------------

.. automodule:: datadog_api_client.v2.model.role_update_data
   :members:
   :show-inheritance:

role\_update\_request
---------------------

.. automodule:: datadog_api_client.v2.model.role_update_request
   :members:
   :show-inheritance:

role\_update\_response
----------------------

.. automodule:: datadog_api_client.v2.model.role_update_response
   :members:
   :show-inheritance:

role\_update\_response\_data
----------------------------

.. automodule:: datadog_api_client.v2.model.role_update_response_data
   :members:
   :show-inheritance:

roles\_response
---------------

.. automodule:: datadog_api_client.v2.model.roles_response
   :members:
   :show-inheritance:

roles\_sort
-----------

.. automodule:: datadog_api_client.v2.model.roles_sort
   :members:
   :show-inheritance:

roles\_type
-----------

.. automodule:: datadog_api_client.v2.model.roles_type
   :members:
   :show-inheritance:

rum\_aggregate\_bucket\_value
-----------------------------

.. automodule:: datadog_api_client.v2.model.rum_aggregate_bucket_value
   :members:
   :show-inheritance:

rum\_aggregate\_bucket\_value\_timeseries
-----------------------------------------

.. automodule:: datadog_api_client.v2.model.rum_aggregate_bucket_value_timeseries
   :members:
   :show-inheritance:

rum\_aggregate\_bucket\_value\_timeseries\_point
------------------------------------------------

.. automodule:: datadog_api_client.v2.model.rum_aggregate_bucket_value_timeseries_point
   :members:
   :show-inheritance:

rum\_aggregate\_request
-----------------------

.. automodule:: datadog_api_client.v2.model.rum_aggregate_request
   :members:
   :show-inheritance:

rum\_aggregate\_sort
--------------------

.. automodule:: datadog_api_client.v2.model.rum_aggregate_sort
   :members:
   :show-inheritance:

rum\_aggregate\_sort\_type
--------------------------

.. automodule:: datadog_api_client.v2.model.rum_aggregate_sort_type
   :members:
   :show-inheritance:

rum\_aggregation\_buckets\_response
-----------------------------------

.. automodule:: datadog_api_client.v2.model.rum_aggregation_buckets_response
   :members:
   :show-inheritance:

rum\_aggregation\_function
--------------------------

.. automodule:: datadog_api_client.v2.model.rum_aggregation_function
   :members:
   :show-inheritance:

rum\_analytics\_aggregate\_response
-----------------------------------

.. automodule:: datadog_api_client.v2.model.rum_analytics_aggregate_response
   :members:
   :show-inheritance:

rum\_application
----------------

.. automodule:: datadog_api_client.v2.model.rum_application
   :members:
   :show-inheritance:

rum\_application\_attributes
----------------------------

.. automodule:: datadog_api_client.v2.model.rum_application_attributes
   :members:
   :show-inheritance:

rum\_application\_create
------------------------

.. automodule:: datadog_api_client.v2.model.rum_application_create
   :members:
   :show-inheritance:

rum\_application\_create\_attributes
------------------------------------

.. automodule:: datadog_api_client.v2.model.rum_application_create_attributes
   :members:
   :show-inheritance:

rum\_application\_create\_request
---------------------------------

.. automodule:: datadog_api_client.v2.model.rum_application_create_request
   :members:
   :show-inheritance:

rum\_application\_create\_type
------------------------------

.. automodule:: datadog_api_client.v2.model.rum_application_create_type
   :members:
   :show-inheritance:

rum\_application\_list
----------------------

.. automodule:: datadog_api_client.v2.model.rum_application_list
   :members:
   :show-inheritance:

rum\_application\_list\_attributes
----------------------------------

.. automodule:: datadog_api_client.v2.model.rum_application_list_attributes
   :members:
   :show-inheritance:

rum\_application\_list\_type
----------------------------

.. automodule:: datadog_api_client.v2.model.rum_application_list_type
   :members:
   :show-inheritance:

rum\_application\_response
--------------------------

.. automodule:: datadog_api_client.v2.model.rum_application_response
   :members:
   :show-inheritance:

rum\_application\_type
----------------------

.. automodule:: datadog_api_client.v2.model.rum_application_type
   :members:
   :show-inheritance:

rum\_application\_update
------------------------

.. automodule:: datadog_api_client.v2.model.rum_application_update
   :members:
   :show-inheritance:

rum\_application\_update\_attributes
------------------------------------

.. automodule:: datadog_api_client.v2.model.rum_application_update_attributes
   :members:
   :show-inheritance:

rum\_application\_update\_request
---------------------------------

.. automodule:: datadog_api_client.v2.model.rum_application_update_request
   :members:
   :show-inheritance:

rum\_application\_update\_type
------------------------------

.. automodule:: datadog_api_client.v2.model.rum_application_update_type
   :members:
   :show-inheritance:

rum\_applications\_response
---------------------------

.. automodule:: datadog_api_client.v2.model.rum_applications_response
   :members:
   :show-inheritance:

rum\_bucket\_response
---------------------

.. automodule:: datadog_api_client.v2.model.rum_bucket_response
   :members:
   :show-inheritance:

rum\_compute
------------

.. automodule:: datadog_api_client.v2.model.rum_compute
   :members:
   :show-inheritance:

rum\_compute\_type
------------------

.. automodule:: datadog_api_client.v2.model.rum_compute_type
   :members:
   :show-inheritance:

rum\_event
----------

.. automodule:: datadog_api_client.v2.model.rum_event
   :members:
   :show-inheritance:

rum\_event\_attributes
----------------------

.. automodule:: datadog_api_client.v2.model.rum_event_attributes
   :members:
   :show-inheritance:

rum\_event\_type
----------------

.. automodule:: datadog_api_client.v2.model.rum_event_type
   :members:
   :show-inheritance:

rum\_events\_response
---------------------

.. automodule:: datadog_api_client.v2.model.rum_events_response
   :members:
   :show-inheritance:

rum\_group\_by
--------------

.. automodule:: datadog_api_client.v2.model.rum_group_by
   :members:
   :show-inheritance:

rum\_group\_by\_histogram
-------------------------

.. automodule:: datadog_api_client.v2.model.rum_group_by_histogram
   :members:
   :show-inheritance:

rum\_group\_by\_missing
-----------------------

.. automodule:: datadog_api_client.v2.model.rum_group_by_missing
   :members:
   :show-inheritance:

rum\_group\_by\_total
---------------------

.. automodule:: datadog_api_client.v2.model.rum_group_by_total
   :members:
   :show-inheritance:

rum\_query\_filter
------------------

.. automodule:: datadog_api_client.v2.model.rum_query_filter
   :members:
   :show-inheritance:

rum\_query\_options
-------------------

.. automodule:: datadog_api_client.v2.model.rum_query_options
   :members:
   :show-inheritance:

rum\_query\_page\_options
-------------------------

.. automodule:: datadog_api_client.v2.model.rum_query_page_options
   :members:
   :show-inheritance:

rum\_response\_links
--------------------

.. automodule:: datadog_api_client.v2.model.rum_response_links
   :members:
   :show-inheritance:

rum\_response\_metadata
-----------------------

.. automodule:: datadog_api_client.v2.model.rum_response_metadata
   :members:
   :show-inheritance:

rum\_response\_page
-------------------

.. automodule:: datadog_api_client.v2.model.rum_response_page
   :members:
   :show-inheritance:

rum\_response\_status
---------------------

.. automodule:: datadog_api_client.v2.model.rum_response_status
   :members:
   :show-inheritance:

rum\_search\_events\_request
----------------------------

.. automodule:: datadog_api_client.v2.model.rum_search_events_request
   :members:
   :show-inheritance:

rum\_sort
---------

.. automodule:: datadog_api_client.v2.model.rum_sort
   :members:
   :show-inheritance:

rum\_sort\_order
----------------

.. automodule:: datadog_api_client.v2.model.rum_sort_order
   :members:
   :show-inheritance:

rum\_warning
------------

.. automodule:: datadog_api_client.v2.model.rum_warning
   :members:
   :show-inheritance:

saml\_assertion\_attribute
--------------------------

.. automodule:: datadog_api_client.v2.model.saml_assertion_attribute
   :members:
   :show-inheritance:

saml\_assertion\_attribute\_attributes
--------------------------------------

.. automodule:: datadog_api_client.v2.model.saml_assertion_attribute_attributes
   :members:
   :show-inheritance:

saml\_assertion\_attributes\_type
---------------------------------

.. automodule:: datadog_api_client.v2.model.saml_assertion_attributes_type
   :members:
   :show-inheritance:

scalar\_column
--------------

.. automodule:: datadog_api_client.v2.model.scalar_column
   :members:
   :show-inheritance:

scalar\_formula\_query\_request
-------------------------------

.. automodule:: datadog_api_client.v2.model.scalar_formula_query_request
   :members:
   :show-inheritance:

scalar\_formula\_query\_response
--------------------------------

.. automodule:: datadog_api_client.v2.model.scalar_formula_query_response
   :members:
   :show-inheritance:

scalar\_formula\_request
------------------------

.. automodule:: datadog_api_client.v2.model.scalar_formula_request
   :members:
   :show-inheritance:

scalar\_formula\_request\_attributes
------------------------------------

.. automodule:: datadog_api_client.v2.model.scalar_formula_request_attributes
   :members:
   :show-inheritance:

scalar\_formula\_request\_queries
---------------------------------

.. automodule:: datadog_api_client.v2.model.scalar_formula_request_queries
   :members:
   :show-inheritance:

scalar\_formula\_request\_type
------------------------------

.. automodule:: datadog_api_client.v2.model.scalar_formula_request_type
   :members:
   :show-inheritance:

scalar\_formula\_response\_atrributes
-------------------------------------

.. automodule:: datadog_api_client.v2.model.scalar_formula_response_atrributes
   :members:
   :show-inheritance:

scalar\_formula\_response\_type
-------------------------------

.. automodule:: datadog_api_client.v2.model.scalar_formula_response_type
   :members:
   :show-inheritance:

scalar\_query
-------------

.. automodule:: datadog_api_client.v2.model.scalar_query
   :members:
   :show-inheritance:

scalar\_response
----------------

.. automodule:: datadog_api_client.v2.model.scalar_response
   :members:
   :show-inheritance:

scalar\_response\_series\_list
------------------------------

.. automodule:: datadog_api_client.v2.model.scalar_response_series_list
   :members:
   :show-inheritance:

security\_filter
----------------

.. automodule:: datadog_api_client.v2.model.security_filter
   :members:
   :show-inheritance:

security\_filter\_attributes
----------------------------

.. automodule:: datadog_api_client.v2.model.security_filter_attributes
   :members:
   :show-inheritance:

security\_filter\_create\_attributes
------------------------------------

.. automodule:: datadog_api_client.v2.model.security_filter_create_attributes
   :members:
   :show-inheritance:

security\_filter\_create\_data
------------------------------

.. automodule:: datadog_api_client.v2.model.security_filter_create_data
   :members:
   :show-inheritance:

security\_filter\_create\_request
---------------------------------

.. automodule:: datadog_api_client.v2.model.security_filter_create_request
   :members:
   :show-inheritance:

security\_filter\_exclusion\_filter
-----------------------------------

.. automodule:: datadog_api_client.v2.model.security_filter_exclusion_filter
   :members:
   :show-inheritance:

security\_filter\_exclusion\_filter\_response
---------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_filter_exclusion_filter_response
   :members:
   :show-inheritance:

security\_filter\_filtered\_data\_type
--------------------------------------

.. automodule:: datadog_api_client.v2.model.security_filter_filtered_data_type
   :members:
   :show-inheritance:

security\_filter\_meta
----------------------

.. automodule:: datadog_api_client.v2.model.security_filter_meta
   :members:
   :show-inheritance:

security\_filter\_response
--------------------------

.. automodule:: datadog_api_client.v2.model.security_filter_response
   :members:
   :show-inheritance:

security\_filter\_type
----------------------

.. automodule:: datadog_api_client.v2.model.security_filter_type
   :members:
   :show-inheritance:

security\_filter\_update\_attributes
------------------------------------

.. automodule:: datadog_api_client.v2.model.security_filter_update_attributes
   :members:
   :show-inheritance:

security\_filter\_update\_data
------------------------------

.. automodule:: datadog_api_client.v2.model.security_filter_update_data
   :members:
   :show-inheritance:

security\_filter\_update\_request
---------------------------------

.. automodule:: datadog_api_client.v2.model.security_filter_update_request
   :members:
   :show-inheritance:

security\_filters\_response
---------------------------

.. automodule:: datadog_api_client.v2.model.security_filters_response
   :members:
   :show-inheritance:

security\_monitoring\_filter
----------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_filter
   :members:
   :show-inheritance:

security\_monitoring\_filter\_action
------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_filter_action
   :members:
   :show-inheritance:

security\_monitoring\_list\_rules\_response
-------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_list_rules_response
   :members:
   :show-inheritance:

security\_monitoring\_rule\_case
--------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_case
   :members:
   :show-inheritance:

security\_monitoring\_rule\_case\_create
----------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_case_create
   :members:
   :show-inheritance:

security\_monitoring\_rule\_create\_payload
-------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_create_payload
   :members:
   :show-inheritance:

security\_monitoring\_rule\_detection\_method
---------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_detection_method
   :members:
   :show-inheritance:

security\_monitoring\_rule\_evaluation\_window
----------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_evaluation_window
   :members:
   :show-inheritance:

security\_monitoring\_rule\_hardcoded\_evaluator\_type
------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_hardcoded_evaluator_type
   :members:
   :show-inheritance:

security\_monitoring\_rule\_impossible\_travel\_options
-------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_impossible_travel_options
   :members:
   :show-inheritance:

security\_monitoring\_rule\_keep\_alive
---------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_keep_alive
   :members:
   :show-inheritance:

security\_monitoring\_rule\_max\_signal\_duration
-------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_max_signal_duration
   :members:
   :show-inheritance:

security\_monitoring\_rule\_new\_value\_options
-----------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_new_value_options
   :members:
   :show-inheritance:

security\_monitoring\_rule\_new\_value\_options\_forget\_after
--------------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_new_value_options_forget_after
   :members:
   :show-inheritance:

security\_monitoring\_rule\_new\_value\_options\_learning\_duration
-------------------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_new_value_options_learning_duration
   :members:
   :show-inheritance:

security\_monitoring\_rule\_new\_value\_options\_learning\_method
-----------------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_new_value_options_learning_method
   :members:
   :show-inheritance:

security\_monitoring\_rule\_new\_value\_options\_learning\_threshold
--------------------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_new_value_options_learning_threshold
   :members:
   :show-inheritance:

security\_monitoring\_rule\_options
-----------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_options
   :members:
   :show-inheritance:

security\_monitoring\_rule\_query
---------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_query
   :members:
   :show-inheritance:

security\_monitoring\_rule\_query\_aggregation
----------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_query_aggregation
   :members:
   :show-inheritance:

security\_monitoring\_rule\_response
------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_response
   :members:
   :show-inheritance:

security\_monitoring\_rule\_severity
------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_severity
   :members:
   :show-inheritance:

security\_monitoring\_rule\_type\_create
----------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_type_create
   :members:
   :show-inheritance:

security\_monitoring\_rule\_type\_read
--------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_type_read
   :members:
   :show-inheritance:

security\_monitoring\_rule\_update\_payload
-------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_rule_update_payload
   :members:
   :show-inheritance:

security\_monitoring\_signal
----------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal
   :members:
   :show-inheritance:

security\_monitoring\_signal\_archive\_reason
---------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_archive_reason
   :members:
   :show-inheritance:

security\_monitoring\_signal\_assignee\_update\_attributes
----------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_assignee_update_attributes
   :members:
   :show-inheritance:

security\_monitoring\_signal\_assignee\_update\_data
----------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_assignee_update_data
   :members:
   :show-inheritance:

security\_monitoring\_signal\_assignee\_update\_request
-------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_assignee_update_request
   :members:
   :show-inheritance:

security\_monitoring\_signal\_attributes
----------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_attributes
   :members:
   :show-inheritance:

security\_monitoring\_signal\_incident\_ids
-------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_incident_ids
   :members:
   :show-inheritance:

security\_monitoring\_signal\_incidents\_update\_attributes
-----------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_incidents_update_attributes
   :members:
   :show-inheritance:

security\_monitoring\_signal\_incidents\_update\_data
-----------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_incidents_update_data
   :members:
   :show-inheritance:

security\_monitoring\_signal\_incidents\_update\_request
--------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_incidents_update_request
   :members:
   :show-inheritance:

security\_monitoring\_signal\_list\_request
-------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_list_request
   :members:
   :show-inheritance:

security\_monitoring\_signal\_list\_request\_filter
---------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_list_request_filter
   :members:
   :show-inheritance:

security\_monitoring\_signal\_list\_request\_page
-------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_list_request_page
   :members:
   :show-inheritance:

security\_monitoring\_signal\_rule\_create\_payload
---------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_rule_create_payload
   :members:
   :show-inheritance:

security\_monitoring\_signal\_rule\_query
-----------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_rule_query
   :members:
   :show-inheritance:

security\_monitoring\_signal\_rule\_response
--------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_rule_response
   :members:
   :show-inheritance:

security\_monitoring\_signal\_rule\_response\_query
---------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_rule_response_query
   :members:
   :show-inheritance:

security\_monitoring\_signal\_rule\_type
----------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_rule_type
   :members:
   :show-inheritance:

security\_monitoring\_signal\_state
-----------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_state
   :members:
   :show-inheritance:

security\_monitoring\_signal\_state\_update\_attributes
-------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_state_update_attributes
   :members:
   :show-inheritance:

security\_monitoring\_signal\_state\_update\_data
-------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_state_update_data
   :members:
   :show-inheritance:

security\_monitoring\_signal\_state\_update\_request
----------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_state_update_request
   :members:
   :show-inheritance:

security\_monitoring\_signal\_triage\_attributes
------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_triage_attributes
   :members:
   :show-inheritance:

security\_monitoring\_signal\_triage\_update\_data
--------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_triage_update_data
   :members:
   :show-inheritance:

security\_monitoring\_signal\_triage\_update\_response
------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_triage_update_response
   :members:
   :show-inheritance:

security\_monitoring\_signal\_type
----------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signal_type
   :members:
   :show-inheritance:

security\_monitoring\_signals\_list\_response
---------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signals_list_response
   :members:
   :show-inheritance:

security\_monitoring\_signals\_list\_response\_links
----------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signals_list_response_links
   :members:
   :show-inheritance:

security\_monitoring\_signals\_list\_response\_meta
---------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signals_list_response_meta
   :members:
   :show-inheritance:

security\_monitoring\_signals\_list\_response\_meta\_page
---------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signals_list_response_meta_page
   :members:
   :show-inheritance:

security\_monitoring\_signals\_sort
-----------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_signals_sort
   :members:
   :show-inheritance:

security\_monitoring\_standard\_rule\_create\_payload
-----------------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_standard_rule_create_payload
   :members:
   :show-inheritance:

security\_monitoring\_standard\_rule\_query
-------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_standard_rule_query
   :members:
   :show-inheritance:

security\_monitoring\_standard\_rule\_response
----------------------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_standard_rule_response
   :members:
   :show-inheritance:

security\_monitoring\_triage\_user
----------------------------------

.. automodule:: datadog_api_client.v2.model.security_monitoring_triage_user
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_config\_request
-----------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_config_request
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_configuration
---------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_configuration
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_configuration\_data
---------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_configuration_data
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_configuration\_relationships
------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_configuration_relationships
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_configuration\_type
---------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_configuration_type
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_create\_group\_response
-------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_create_group_response
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_create\_rule\_response
------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_create_rule_response
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_filter
--------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_filter
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_get\_config\_included\_array
------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_get_config_included_array
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_get\_config\_included\_item
-----------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_get_config_included_item
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_get\_config\_response
-----------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_get_config_response
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_get\_config\_response\_data
-----------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_get_config_response_data
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_group
-------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_group
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_group\_attributes
-------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_group_attributes
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_group\_create
---------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_group_create
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_group\_create\_request
------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_group_create_request
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_group\_data
-------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_group_data
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_group\_delete\_request
------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_group_delete_request
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_group\_delete\_response
-------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_group_delete_response
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_group\_included\_item
-----------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_group_included_item
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_group\_item
-------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_group_item
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_group\_list
-------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_group_list
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_group\_relationships
----------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_group_relationships
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_group\_response
-----------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_group_response
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_group\_type
-------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_group_type
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_group\_update
---------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_group_update
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_group\_update\_request
------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_group_update_request
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_group\_update\_response
-------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_group_update_response
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_meta
------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_meta
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_meta\_version\_only
---------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_meta_version_only
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_product
---------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_product
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_reorder\_config
-----------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_reorder_config
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_reorder\_groups\_response
---------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_reorder_groups_response
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_rule
------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_rule
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_rule\_attributes
------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_rule_attributes
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_rule\_create
--------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_rule_create
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_rule\_create\_request
-----------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_rule_create_request
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_rule\_data
------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_rule_data
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_rule\_delete\_request
-----------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_rule_delete_request
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_rule\_delete\_response
------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_rule_delete_response
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_rule\_included\_item
----------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_rule_included_item
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_rule\_relationships
---------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_rule_relationships
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_rule\_response
----------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_rule_response
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_rule\_type
------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_rule_type
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_rule\_update
--------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_rule_update
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_rule\_update\_request
-----------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_rule_update_request
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_rule\_update\_response
------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_rule_update_response
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_standard\_pattern
-------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_standard_pattern
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_standard\_pattern\_attributes
-------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_standard_pattern_attributes
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_standard\_pattern\_data
-------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_standard_pattern_data
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_standard\_pattern\_type
-------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_standard_pattern_type
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_standard\_patterns\_response
------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_standard_patterns_response
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_standard\_patterns\_response\_data
------------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_standard_patterns_response_data
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_standard\_patterns\_response\_item
------------------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_standard_patterns_response_item
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_text\_replacement
-------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_text_replacement
   :members:
   :show-inheritance:

sensitive\_data\_scanner\_text\_replacement\_type
-------------------------------------------------

.. automodule:: datadog_api_client.v2.model.sensitive_data_scanner_text_replacement_type
   :members:
   :show-inheritance:

service\_account\_create\_attributes
------------------------------------

.. automodule:: datadog_api_client.v2.model.service_account_create_attributes
   :members:
   :show-inheritance:

service\_account\_create\_data
------------------------------

.. automodule:: datadog_api_client.v2.model.service_account_create_data
   :members:
   :show-inheritance:

service\_account\_create\_request
---------------------------------

.. automodule:: datadog_api_client.v2.model.service_account_create_request
   :members:
   :show-inheritance:

service\_definition\_create\_response
-------------------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_create_response
   :members:
   :show-inheritance:

service\_definition\_data
-------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_data
   :members:
   :show-inheritance:

service\_definition\_data\_attributes
-------------------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_data_attributes
   :members:
   :show-inheritance:

service\_definition\_get\_response
----------------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_get_response
   :members:
   :show-inheritance:

service\_definition\_meta
-------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_meta
   :members:
   :show-inheritance:

service\_definition\_schema
---------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_schema
   :members:
   :show-inheritance:

service\_definition\_v1
-----------------------

.. automodule:: datadog_api_client.v2.model.service_definition_v1
   :members:
   :show-inheritance:

service\_definition\_v1\_contact
--------------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_v1_contact
   :members:
   :show-inheritance:

service\_definition\_v1\_info
-----------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_v1_info
   :members:
   :show-inheritance:

service\_definition\_v1\_integrations
-------------------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_v1_integrations
   :members:
   :show-inheritance:

service\_definition\_v1\_org
----------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_v1_org
   :members:
   :show-inheritance:

service\_definition\_v1\_resource
---------------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_v1_resource
   :members:
   :show-inheritance:

service\_definition\_v1\_resource\_type
---------------------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_v1_resource_type
   :members:
   :show-inheritance:

service\_definition\_v2
-----------------------

.. automodule:: datadog_api_client.v2.model.service_definition_v2
   :members:
   :show-inheritance:

service\_definition\_v2\_contact
--------------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_v2_contact
   :members:
   :show-inheritance:

service\_definition\_v2\_doc
----------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_v2_doc
   :members:
   :show-inheritance:

service\_definition\_v2\_email
------------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_v2_email
   :members:
   :show-inheritance:

service\_definition\_v2\_email\_type
------------------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_v2_email_type
   :members:
   :show-inheritance:

service\_definition\_v2\_integrations
-------------------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_v2_integrations
   :members:
   :show-inheritance:

service\_definition\_v2\_link
-----------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_v2_link
   :members:
   :show-inheritance:

service\_definition\_v2\_link\_type
-----------------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_v2_link_type
   :members:
   :show-inheritance:

service\_definition\_v2\_opsgenie
---------------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_v2_opsgenie
   :members:
   :show-inheritance:

service\_definition\_v2\_opsgenie\_region
-----------------------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_v2_opsgenie_region
   :members:
   :show-inheritance:

service\_definition\_v2\_repo
-----------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_v2_repo
   :members:
   :show-inheritance:

service\_definition\_v2\_slack
------------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_v2_slack
   :members:
   :show-inheritance:

service\_definition\_v2\_slack\_type
------------------------------------

.. automodule:: datadog_api_client.v2.model.service_definition_v2_slack_type
   :members:
   :show-inheritance:

service\_definitions\_create\_request
-------------------------------------

.. automodule:: datadog_api_client.v2.model.service_definitions_create_request
   :members:
   :show-inheritance:

service\_definitions\_list\_response
------------------------------------

.. automodule:: datadog_api_client.v2.model.service_definitions_list_response
   :members:
   :show-inheritance:

tags\_event\_attribute
----------------------

.. automodule:: datadog_api_client.v2.model.tags_event_attribute
   :members:
   :show-inheritance:

timeseries\_formula\_query\_request
-----------------------------------

.. automodule:: datadog_api_client.v2.model.timeseries_formula_query_request
   :members:
   :show-inheritance:

timeseries\_formula\_query\_response
------------------------------------

.. automodule:: datadog_api_client.v2.model.timeseries_formula_query_response
   :members:
   :show-inheritance:

timeseries\_formula\_request
----------------------------

.. automodule:: datadog_api_client.v2.model.timeseries_formula_request
   :members:
   :show-inheritance:

timeseries\_formula\_request\_attributes
----------------------------------------

.. automodule:: datadog_api_client.v2.model.timeseries_formula_request_attributes
   :members:
   :show-inheritance:

timeseries\_formula\_request\_queries
-------------------------------------

.. automodule:: datadog_api_client.v2.model.timeseries_formula_request_queries
   :members:
   :show-inheritance:

timeseries\_formula\_request\_type
----------------------------------

.. automodule:: datadog_api_client.v2.model.timeseries_formula_request_type
   :members:
   :show-inheritance:

timeseries\_formula\_response\_type
-----------------------------------

.. automodule:: datadog_api_client.v2.model.timeseries_formula_response_type
   :members:
   :show-inheritance:

timeseries\_query
-----------------

.. automodule:: datadog_api_client.v2.model.timeseries_query
   :members:
   :show-inheritance:

timeseries\_response
--------------------

.. automodule:: datadog_api_client.v2.model.timeseries_response
   :members:
   :show-inheritance:

timeseries\_response\_attributes
--------------------------------

.. automodule:: datadog_api_client.v2.model.timeseries_response_attributes
   :members:
   :show-inheritance:

timeseries\_response\_series
----------------------------

.. automodule:: datadog_api_client.v2.model.timeseries_response_series
   :members:
   :show-inheritance:

timeseries\_response\_series\_list
----------------------------------

.. automodule:: datadog_api_client.v2.model.timeseries_response_series_list
   :members:
   :show-inheritance:

timeseries\_response\_times
---------------------------

.. automodule:: datadog_api_client.v2.model.timeseries_response_times
   :members:
   :show-inheritance:

timeseries\_response\_values
----------------------------

.. automodule:: datadog_api_client.v2.model.timeseries_response_values
   :members:
   :show-inheritance:

timeseries\_response\_values\_list
----------------------------------

.. automodule:: datadog_api_client.v2.model.timeseries_response_values_list
   :members:
   :show-inheritance:

unit
----

.. automodule:: datadog_api_client.v2.model.unit
   :members:
   :show-inheritance:

usage\_application\_security\_monitoring\_response
--------------------------------------------------

.. automodule:: datadog_api_client.v2.model.usage_application_security_monitoring_response
   :members:
   :show-inheritance:

usage\_attributes\_object
-------------------------

.. automodule:: datadog_api_client.v2.model.usage_attributes_object
   :members:
   :show-inheritance:

usage\_data\_object
-------------------

.. automodule:: datadog_api_client.v2.model.usage_data_object
   :members:
   :show-inheritance:

usage\_lambda\_traced\_invocations\_response
--------------------------------------------

.. automodule:: datadog_api_client.v2.model.usage_lambda_traced_invocations_response
   :members:
   :show-inheritance:

usage\_observability\_pipelines\_response
-----------------------------------------

.. automodule:: datadog_api_client.v2.model.usage_observability_pipelines_response
   :members:
   :show-inheritance:

usage\_time\_series\_object
---------------------------

.. automodule:: datadog_api_client.v2.model.usage_time_series_object
   :members:
   :show-inheritance:

usage\_time\_series\_type
-------------------------

.. automodule:: datadog_api_client.v2.model.usage_time_series_type
   :members:
   :show-inheritance:

user
----

.. automodule:: datadog_api_client.v2.model.user
   :members:
   :show-inheritance:

user\_attributes
----------------

.. automodule:: datadog_api_client.v2.model.user_attributes
   :members:
   :show-inheritance:

user\_create\_attributes
------------------------

.. automodule:: datadog_api_client.v2.model.user_create_attributes
   :members:
   :show-inheritance:

user\_create\_data
------------------

.. automodule:: datadog_api_client.v2.model.user_create_data
   :members:
   :show-inheritance:

user\_create\_request
---------------------

.. automodule:: datadog_api_client.v2.model.user_create_request
   :members:
   :show-inheritance:

user\_invitation\_data
----------------------

.. automodule:: datadog_api_client.v2.model.user_invitation_data
   :members:
   :show-inheritance:

user\_invitation\_data\_attributes
----------------------------------

.. automodule:: datadog_api_client.v2.model.user_invitation_data_attributes
   :members:
   :show-inheritance:

user\_invitation\_relationships
-------------------------------

.. automodule:: datadog_api_client.v2.model.user_invitation_relationships
   :members:
   :show-inheritance:

user\_invitation\_response
--------------------------

.. automodule:: datadog_api_client.v2.model.user_invitation_response
   :members:
   :show-inheritance:

user\_invitation\_response\_data
--------------------------------

.. automodule:: datadog_api_client.v2.model.user_invitation_response_data
   :members:
   :show-inheritance:

user\_invitations\_request
--------------------------

.. automodule:: datadog_api_client.v2.model.user_invitations_request
   :members:
   :show-inheritance:

user\_invitations\_response
---------------------------

.. automodule:: datadog_api_client.v2.model.user_invitations_response
   :members:
   :show-inheritance:

user\_invitations\_type
-----------------------

.. automodule:: datadog_api_client.v2.model.user_invitations_type
   :members:
   :show-inheritance:

user\_relationships
-------------------

.. automodule:: datadog_api_client.v2.model.user_relationships
   :members:
   :show-inheritance:

user\_response
--------------

.. automodule:: datadog_api_client.v2.model.user_response
   :members:
   :show-inheritance:

user\_response\_included\_item
------------------------------

.. automodule:: datadog_api_client.v2.model.user_response_included_item
   :members:
   :show-inheritance:

user\_response\_relationships
-----------------------------

.. automodule:: datadog_api_client.v2.model.user_response_relationships
   :members:
   :show-inheritance:

user\_update\_attributes
------------------------

.. automodule:: datadog_api_client.v2.model.user_update_attributes
   :members:
   :show-inheritance:

user\_update\_data
------------------

.. automodule:: datadog_api_client.v2.model.user_update_data
   :members:
   :show-inheritance:

user\_update\_request
---------------------

.. automodule:: datadog_api_client.v2.model.user_update_request
   :members:
   :show-inheritance:

users\_response
---------------

.. automodule:: datadog_api_client.v2.model.users_response
   :members:
   :show-inheritance:

users\_type
-----------

.. automodule:: datadog_api_client.v2.model.users_type
   :members:
   :show-inheritance:


.. automodule:: datadog_api_client.v2.model
   :members:
   :show-inheritance:
